package PAR::StrippedPARL::Dynamic;
use strict;
use warnings;
use vars qw/$VERSION/;
$VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut

__DATA__

M?T5,1@(!`0````````````(`/@`!````("1```````!``````````%C;````
M`````````$``.``(`$``&P`:``8````%````0`````````!``$```````$``
M0```````P`$```````#``0````````@``````````P````0``````@``````
M```"0`````````)````````<`````````!P``````````0`````````!````
M!0````````````````!``````````$```````$S3````````3-,`````````
M`"````````$````&````4-,```````!0TV```````%#38```````^`0`````
M``#@%0``````````(````````@````8```!XTP```````'C38```````>--@
M`````````@`````````"````````"``````````$````!````!P"````````
M'`)````````<`D```````"``````````(``````````$`````````%#E=&0$
M````%,T````````4S4```````!3-0```````1`$```````!$`0````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````"``````````O;&EB-C0O;&0M;&EN=7@M>#@V+38T+G-O+C(`
M!````!`````!````1TY5```````"````!@````D`````````)0```$H````(
M````"0```&`<H*````80@`@```(`0`D!P0*@"`!!40"`$```A`1```````=`
M`((X$H``A<0`I$4(``!@8$9).``)%<HF!(D`````2@```$T```!/````4```
M`%(```!5````5P````````!8````60````````!:````7````%X`````````
M7P``````````````8````&$```````````````````!D````9P```&@```!K
M````;@```&\```!R`````````'0```!U````=@```'D`````````YO\PHL[>
M1RVCX/M)OJ*%5`<61B`?^-$-2`NMA;=]_DRFW:-KZM/O#K$Z=08NQ9NV%ZI7
M=]O-XYZ)GFS\:PE#U@PZEPN?G,FB3%U$U,6)!9`-%.*>(?_D#@N*$%>R`8MO
MQ+F<0&M_FGQNQ=\?V'%8''N9=?F[XY)\U&34?*Q+X\#K?"2I,F+;[>"G`@J#
M%YKDB_U'Q6:OS&9@%LE9>_!*:^)'Q@%#1=7L1^PS.GU!CL7"Y3\LN'C;%+>`
MA60@\]DP\MO3'?JA;&"YC?$.````````````````````````````````YP``
M`!(``````````````!4!````````#0$``!(```````````````4`````````
MAP```!(``````````````"<`````````I`(``!(``````````````&P`````
M````4P(``!(``````````````'`$````````,`,``!(``````````````'P!
M````````#````"``````````````````````````&P```"``````````````
M````````````_@$``!$```````````````@`````````G0,``!(`````````
M`````(D#````````[@(``!(``````````````/$`````````8`,``!(`````
M`````````(``````````^P(``!(``````````````*H#````````:@(``!(`
M`````````````-X!````````S`,``!(``````````````*4!````````N@$`
M`!(``````````````%`$````````DP```!(``````````````(T#````````
MJ@$``!(``````````````&01````````.`$``!(``````````````)P`````
M````&P,``!(``````````````"4`````````4P,``!(``````````````"4`
M````````=0$``!(``````````````%8!````````T````!(`````````````
M`)4`````````-P,``!(``````````````#,`````````.P```!$`````````
M``````@`````````<0(``!(``````````````"L`````````9`$``!(`````
M`````````*D!````````U0$``!(``````````````.0!````````$@$``!(`
M`````````````)X!````````=P,``!(``````````````*$`````````A@,`
M`!(``````````````#H`````````+P```!(``````````````%L'````````
MMP(``!(``````````````!$"````````\P(``!(``````````````)``````
M````4P$``!$```````````````@`````````90,``!(``````````````!D`
M````````:````!(``````````````)4'````````H@(``!(`````````````
M`#8`````````+@$``!$``````````````!``````````60,``!(`````````
M``````(!````````3`,``!(``````````````"L!````````P0```!(`````
M`````````%4!````````E`,``!(``````````````"4`````````PP$``!(`
M`````````````(D`````````%@(``!(``````````````%T"````````%`,`
M`!(``````````````.(`````````M@,``!(``````````````'0!````````
M\@,``!(``````````````%\`````````"`(``!(``````````````*L/````
M````?P,``!(``````````````/4`````````/@,``!(``````````````%0`
M````````(@$``!(``````````````)$`````````Q0,``!(`````````````
M``,#````````10,``!(``````````````/$`````````L`(``!(`````````
M`````%``````````#`,``!(``````````````'8(````````Z`,``!(`````
M`````````%\`````````7@(``!(``````````````*X`````````I`,``!(`
M`````````````(``````````J@(``!(``````````````'D`````````]0``
M`!(``````````````(L``````````P,``!(``````````````#,`````````
MO@,``!(``````````````"4`````````2`(``!(``````````````(T`````
M````*`,``!(``````````````"8$````````XP$``!(``````````````"T$
M````````@P$``!(``````````````'L`````````D0$``!$`````````````
M``@`````````K`,``!(``````````````-4`````````2`$``!(`````````
M``````X`````````(@,``!(``````````````"4`````````40```!(`````
M`````````'L`````````KP```!(``````````````*X)````````QP4``!$`
M#@``?4```````*]-````````\`4``!(`#`#K7D```````)T&````````'`8`
M`!(`#`#Z+D```````,X!`````````@$``!$`&`!TV&````````0`````````
MH0```!$`&`!XV&````````$`````````;P$``!$`&`"(V&````````@`````
M````GP$``!$`&`"8V&````````$`````````+P4``!(`#`!`=4```````"<!
M````````X`,``"$`&`!HV&````````@`````````9`0``!(`#0`8>D``````
M````````````=P```!$`&`"HV&````````@`````````/`0``!(`#`"Y*D``
M``````L`````````,0(``!$`&`!PV&````````0`````````:P4``!(`#``P
M>4```````(L`````````1P```!$`&`"`V&````````@`````````$@4``!``
M%P`(V&``````````````````%`4``"``%P`(V&``````````````````O`0`
M`!(`#`#`=T```````%L!````````[@$``!$`&`"@V&````````@`````````
MWP,``"$`&`!HV&````````@`````````6@0``!(`#``@>4````````(`````
M````#P8``!(`#`#$*D```````'0"````````V@```!$`&`"PV&````````$`
M````````@`0``!(`#`#(,$```````&0`````````W@,``!$`&`!HV&``````
M``@`````````V0,``!(`#`!0;$```````$H"````````L`0``!(`#``H9T``
M`````'@`````````!`0``!``\?](V&``````````````````T04``!(`#`"@
M;D```````%T`````````$`0``!``\?\PZ6``````````````````:@0``!(`
M#`!H:$```````+P#`````````P4``!$`#@!`>D````````0`````````3`4`
M`!(`#`#P<4```````/L`````````&`4``!(`#``@)$``````````````````
MC@0``!(`#`#=*4```````-P`````````Y@0``!(`#`!P=D```````$L!````
M````)`(``!$`&`"0V&````````@`````````I`0``!(`#`")+4```````'$!
M````````UP0``!$`%P!`V&````````@`````````'P4``!(`#```;T``````
M`.0"````````300``!(`#``X+4```````%$`````````_0,``!``\?](V&``
M````````````````P@4``!$`%P`XV&````````@`````````F04``!(`#`!!
M:$```````"<`````````8P4``!(`#`#8)$```````"4`````````>P4``!(`
M#`#P<D```````%8!````````M04``!(`#`"(94```````*`!````````%P$`
M`!$`&`!@V&````````@`````````?`(``!$`&`#`V&```````!,`````````
M_04``!(`#`!:74```````)$!````````904``!(`"@#8'T``````````````
M`````&QI8G!E<FPN<V\`7U]G;6]N7W-T87)T7U\`7TIV7U)E9VES=&5R0VQA
M<W-E<P!097)L7W-V7S)I=@!03%]S=&%C:U]S<`!03%]C;VUP8W8`4&5R;%]S
M879E7V1E<W1R=6-T;W)?>`!P97)L7V-O;G-T<G5C=`!03%]S:6=F<&5?<V%V
M960`4&5R;%]G971?<W8`4&5R;%]A=E]S:&EF=`!03%]E>&ET7V9L86=S`%!E
M<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?<V5T<'9N`%!E<FQ?9F]R;0!03%]D
M;U]U;F1U;7``4&5R;%]S=E]S971I=@!097)L7VYE=U-6<'8`4$Q?:6Y?979A
M;`!P97)L7V9R964`4$Q?;&EN97-T<@!097)L7VUG7W-E=`!03%]S=E]Y97,`
M4&5R;%]S=E\R;6]R=&%L`%!E<FQ?;F5W4E8`4$Q?;6%R:W-T86-K7W!T<@!0
M97)L7W9M97-S`%!,7V]P`%!E<FQ?<W9?<V5T<'8`4&5R;%]N97=35G!V;@!0
M3%]S=&%C:U]B87-E`%!,7W1A:6YT960`4&5R;%]G=E]F971C:'!V`'!E<FQ?
M<G5N`%!E<FQ?<W9?;F5W;6]R=&%L`%!E<FQ?9&]U;G=I;F0`4&5R;%]N97=8
M4P!03%]C=7)S=&%C:VEN9F\`4$Q?8W5R<&%D`'!E<FQ?9&5S=')U8W0`4&5R
M;%]A=E]F971C:`!03%]E=F%L7W)O;W0`4$Q?<&5R;%]D97-T<G5C=%]L979E
M;`!097)L7V-R;V%K`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E
M<FQ?86QL;V,`4$Q?;65M;W)Y7W=R87``;&EB;G-L+G-O+C$`;&EB9&PN<V\N
M,@!D;&-L;W-E`&1L<WEM`&1L;W!E;@!D;&5R<F]R`&QI8FTN<V\N-@!L:6)C
M<GEP="YS;RXQ`&QI8G5T:6PN<V\N,0!L:6)C+G-O+C8`97AI=`!S<')I;G1F
M`'-T<FYC;7``8VQO<V5D:7(`<W1R;F-P>0!S:6=N86P`=6YL:6YK`&UK9&ER
M`')E86QL;V,`;65M8VAR`&=E='!I9`!S=')D=7``<W1R=&]K`'-T<G-T<@!R
M;61I<@!O<&5N-C0`<F5A9`!?7W-T<G1O;%]I;G1E<FYA;`!O<&5N9&ER`&=E
M=&5N=@!?7V-T>7!E7V)?;&]C`')E861L:6YK`&5X96-V<`!L<V5E:S8T`')E
M861D:7(V-`!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA
M:6X`7U]E;G9I<F]N`%]?>'-T870V-`!?7VQX<W1A=#8T`%]E9&%T80!?7V)S
M<U]S=&%R=`!?96YD`"]U<W(O;&EB+W!E<FPU+S4N."XX+W@X-E\V-"UL:6YU
M>"]#3U)%`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A<V5N86UE`%]?;&EB8U]C
M<W5?9FEN:0!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P
M87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`<&%R7V-L96%N=7``
M6%-?1'EN84QO861E<E]D;%]L;V%D7V9I;&4`<VEZ95]L;V%D7VUE7S(`6%-?
M1'EN84QO861E<E]D;%]U;FQO861?9FEL90!?24]?<W1D:6Y?=7-E9`!?7V1A
M=&%?<W1A<G0`8F]O=%]$>6YA3&]A9&5R`%A37T1Y;F%,;V%D97)?9&Q?9FEN
M9%]S>6UB;VP`6%-?1'EN84QO861E<E]D;%]E<G)O<@!X<U]I;FET`%]?;&EB
M8U]C<W5?:6YI=`!84U]$>6YA3&]A9&5R7V1L7VEN<W1A;&Q?>'-U8@!84U])
M;G1E<FYA;'-?4$%27T-,14%24U1!0TL`<&%R7W)M=&UP9&ER`&YA;65?;&]A
M9%]M95\R`%A37T1Y;F%,;V%D97)?9&Q?=6YD969?<WEM8F]L<P!P87)?;6MT
M;7!D:7(`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`'!A<E]I;FET
M7V5N=@!'3$E"0U\R+C(N-0!'3$E"0U\R+C,``````````````@````(`````
M`````@`"``(``@`"``(````````````"``(```````(````````````"``(`
M`P````0``@````(````$`````@`"`````@```````@`"``(````"``(````"
M``(`!``"``(````"``0````"``(````"``````````(````"```````!``$`
M`0````````````$``@`!`````0````$````!``$``0````(``0`!`````0`"
M``$``0`!``$``0`!``$``0`!``$``0````$``0`!``$``0`!``$``0`!``$`
M``````$``0`````````!``$`EP(``!`````@````=1II"0``!``I!@``````
M``$``@#D`@``$``````````3:6D-```#`#4&```0````=1II"0```@`I!@``
M`````'C58```````!@````<``````````````(#58```````!@````D`````
M`````````(C58```````!@```%L``````````````)#58```````!@```!D`
M`````````````)C58```````!@```&T``````````````*#58```````!@``
M`$\``````````````(C88```````!0```$\``````````````*C58```````
M!@```",``````````````+#58```````!@```"<``````````````+C58```
M````!@```%$``````````````,#58```````!@```&H``````````````,C5
M8```````!@```'<``````````````-#58```````!@```&8`````````````
M`-C58```````!@```$0``````````````&#88```````!0```'D`````````
M`````&C88```````!0```&(``````````````'#88```````!0```%8`````
M`````````'388```````!0```$T``````````````'C88```````!0```$X`
M`````````````(#88```````!0```%@``````````````)#88```````!0``
M`&X``````````````)C88```````!0```%```````````````*#88```````
M!0```%P``````````````*C88```````!0```%0``````````````+#88```
M````!0```&```````````````,#88```````!0```'H``````````````/C5
M8```````!P````$```````````````#68```````!P````(`````````````
M``C68```````!P````,``````````````!#68```````!P````0`````````
M`````!C68```````!P````4``````````````"#68```````!P````8`````
M`````````"C68```````!P````H``````````````##68```````!P````L`
M`````````````#C68```````!P````P``````````````$#68```````!P``
M``T``````````````$C68```````!P````X``````````````%#68```````
M!P````\``````````````%C68```````!P```!```````````````&#68```
M````!P```!$``````````````&C68```````!P```!(``````````````'#6
M8```````!P```!,``````````````'C68```````!P```!0`````````````
M`(#68```````!P```!4``````````````(C68```````!P```!8`````````
M`````)#68```````!P```!<``````````````)C68```````!P```!@`````
M`````````*#68```````!P```!H``````````````*C68```````!P```!L`
M`````````````+#68```````!P```!P``````````````+C68```````!P``
M`!T``````````````,#68```````!P```!X``````````````,C68```````
M!P```!\``````````````-#68```````!P```"```````````````-C68```
M````!P```"$``````````````.#68```````!P```"(``````````````.C6
M8```````!P```"0``````````````/#68```````!P```"4`````````````
M`/C68```````!P```"8```````````````#78```````!P```"@`````````
M``````C78```````!P```"D``````````````!#78```````!P```"H`````
M`````````!C78```````!P```"L``````````````"#78```````!P```"P`
M`````````````"C78```````!P```"T``````````````##78```````!P``
M`"X``````````````#C78```````!P```"\``````````````$#78```````
M!P```#```````````````$C78```````!P```#$``````````````%#78```
M````!P```#(``````````````%C78```````!P```#,``````````````&#7
M8```````!P```#0``````````````&C78```````!P```#4`````````````
M`'#78```````!P```#8``````````````'C78```````!P```#<`````````
M`````(#78```````!P```#@``````````````(C78```````!P```#D`````
M`````````)#78```````!P```#H``````````````)C78```````!P```#L`
M`````````````*#78```````!P```#P``````````````*C78```````!P``
M`#T``````````````+#78```````!P```#X``````````````+C78```````
M!P```#\``````````````,#78```````!P```$```````````````,C78```
M````!P```$$``````````````-#78```````!P```$(``````````````-C7
M8```````!P```$,``````````````.#78```````!P```$4`````````````
M`.C78```````!P```$8``````````````/#78```````!P```$<`````````
M`````/C78```````!P```$@```````````````#88```````!P```$D`````
M`````````$B#[`CH:P0``.C*!```Z/59``!(@\0(P_\U\K4@`/\E]+4@``\?
M0`#_)?*U(`!H`````.G@_____R7JM2``:`$```#IT/____\EXK4@`&@"````
MZ<#_____)=JU(`!H`P```.FP_____R72M2``:`0```#IH/____\ERK4@`&@%
M````Z9#_____)<*U(`!H!@```.F`_____R6ZM2``:`<```#I</____\ELK4@
M`&@(````Z6#_____):JU(`!H"0```.E0_____R6BM2``:`H```#I0/____\E
MFK4@`&@+````Z3#_____)9*U(`!H#````.D@_____R6*M2``:`T```#I$/__
M__\E@K4@`&@.````Z0#_____)7JU(`!H#P```.GP_O___R5RM2``:!````#I
MX/[___\E:K4@`&@1````Z=#^____)6*U(`!H$@```.G`_O___R5:M2``:!,`
M``#IL/[___\E4K4@`&@4````Z:#^____)4JU(`!H%0```.F0_O___R5"M2``
M:!8```#I@/[___\E.K4@`&@7````Z7#^____)3*U(`!H&````.E@_O___R4J
MM2``:!D```#I4/[___\E(K4@`&@:````Z4#^____)1JU(`!H&P```.DP_O__
M_R42M2``:!P```#I(/[___\E"K4@`&@=````Z1#^____)0*U(`!H'@```.D`
M_O___R7ZM"``:!\```#I\/W___\E\K0@`&@@````Z>#]____)>JT(`!H(0``
M`.G0_?___R7BM"``:"(```#IP/W___\EVK0@`&@C````Z;#]____)=*T(`!H
M)````.F@_?___R7*M"``:"4```#ID/W___\EPK0@`&@F````Z8#]____);JT
M(`!H)P```.EP_?___R6RM"``:"@```#I8/W___\EJK0@`&@I````Z5#]____
M):*T(`!H*@```.E`_?___R6:M"``:"L```#I,/W___\EDK0@`&@L````Z2#]
M____)8JT(`!H+0```.D0_?___R6"M"``:"X```#I`/W___\E>K0@`&@O````
MZ?#\____)7*T(`!H,````.G@_/___R5JM"``:#$```#IT/S___\E8K0@`&@R
M````Z<#\____)5JT(`!H,P```.FP_/___R52M"``:#0```#IH/S___\E2K0@
M`&@U````Z9#\____)4*T(`!H-@```.F`_/___R4ZM"``:#<```#I</S___\E
M,K0@`&@X````Z6#\____)2JT(`!H.0```.E0_/___R4BM"``:#H```#I0/S_
M__\E&K0@`&@[````Z3#\____)1*T(`!H/````.D@_/___R4*M"``:#T```#I
M$/S___\E`K0@`&@^````Z0#\____)?JS(`!H/P```.GP^____R7RLR``:$``
M``#IX/O___\EZK,@`&A!````Z=#[__\Q[4F)T5Y(B>)(@^3P4%1)Q\`@>4``
M2,?!,'E``$C'QU!L0`#H9_S___20D$B#[`A(BP4AL2``2(7`=`+_T$B#Q`C#
MD)"0D)"0D)"0D)"0D(`]7;0@``!52(GE=!#K))!(@\`(2(D%C;,@`/_22(L%
MA+,@`$B+$$B%TG7DQ@4QM"```<G##Q]$``!F#Q]$``!52(,]MZX@``!(B>5T
M%K@`````2(7`=`R_<--@`$F)P\E!_^/)PY"054B)Y4B#[!!(QT7X2'I``$B+
M5?B^`&]``+]2>D``Z+7^___)PU5(B>5(@>P@$```2(F]Z.___TB)M>#O__](
MC;7P[___NO\/``"_;GI``.@4_?__B47\@WW\`'X8BT7\@^@!2)@/MH0%\.__
M_X3`=02#;?P!@WW\`'XWBT7\2&/02(V]\.___[XO````Z.;Z__](A<!T&XM%
M_$ACT$B-M?#O__](B[WH[___Z*C\___K$TB+M>#O__](B[WH[___Z(/[___)
MPU5(B>5(@^Q`2(E]R$B)=?A(@WW(`'0,2(L%J[(@`$B%P'4-2,=%T`````#I
MN@```$B+1<A(B47@ZP5(@T7@`4B+5>`/M@*$P'0+2(M-X`^V`3P]=>5(BT7@
MB<)(BT7(B=$IP8G(B47<2(L%6K(@`$B)1>CK6TAC5=Q(BW7(2(M]\.AK^O__
MA<!U04AC1=Q(`T7P#[8`/#UU,DB+5>A(BP4ELB``2(G12"G!2(G(2,'X`XG"
M2(M%^(D02&-%W$@#1?!(@\`!2(E%T.L?2(-%Z`A(BT7H2(L`2(E%\$B#??``
M=9-(QT70`````$B+1=#)PU5(B>5(@^P@2(E]Z$B-=?Q(BWWHN`````#H\O[_
M_\G#54B)Y5-(@^Q82(E]X$B)=;A(BU6X#[8"/#UU!4B#1;@!2(M%N$C'P?__
M__](B46PN`````#\2(M]L/*N2(G(2/?02(/H`8E%]$B-=?!(BWW@N`````#H
ME?[__TB)1<A(@WW(`'1D2(M%R$C'P?____](B46HN`````#\2(M]J/*N2(G(
M2/?02(U0_XM%]$@YP@^"*`$``$B+5;@/M@)(BTW(B`%(BWW(#[8'A,`/E<!(
M@T7(`4B#1;@!A,!UV<=%Q`````#I]`$``$B+!>BP(`!(B478QT74`````.L)
M2(-%V`B#1=0!2(M5V$B+`DB%P'7KBP4XL2``A<!T/HM%U(/``DB82(TTQ0``
M``!(BP6EL"``2(G'Z-7[__](B066L"``2(L%C[`@`$B%P'5IQT7$_____^F#
M`0``QP7LL"```0```(M%U(/``DB82(T\Q0````#HE_C__TB)1=A(@WW8`'4,
MQT7$_____^E-`0``2&-%U$B-%,4`````2(LU-;`@`$B+?=CH1/K__TB+3=A(
MB0TAL"``2&-%U$C!X`-(B<)(BP4/L"``2(T$`DB#P`A(QP``````BT74B47P
M2(M]X$B)?<CK!4B#1<@!2(M5R`^V`H3`=`M(BTW(#[8!/#UUY8M%\(G`2,'@
M`TB)PDB+!<*O(`!(C1P"2(M%R(G"2(M%X(G7*<>)^`-%](/``HG'Z-GW__](
MB0-(BP-(A<!U#,=%Q/_____ICP```(M%\(G`2,'@`TB)PDB+!7>O(`!(C00"
M2(L`2(E%R.L%2(-%R`%(BT7@#[8`2(M5R(@"2(M-R`^V`83`#Y7`2(-%X`&#
M\`&$P'4+2(M]R`^V!SP]=<M(BT7(Q@`]2(-%R`%(BU6X#[8"2(M-R(@!2(M]
MR`^V!X3`#Y7`2(-%R`%(@T6X`83`==G'1<0`````BT7$2(/$6%O)PU5(B>5(
M@^P@2(E]Z.L_BT7\2)A(P>`#2(G"2(L%T*X@`$@!PDB)5>!(BT7@2(/`"$B+
M`$B+5>!(B0)(BU7@2(L"2(7`=`=(@T7@".O;2(UU_$B+?>BX`````.C)^___
M2(7`=:K)PU5(B>5(@>Q`(```2,=%\`````#H2_?__TB-O>#O__^Y@7I``(G"
MOH5Z0`"X`````.B^]___B47\@WW\`'D02,>%R-___P````#IA0```$B-M=#?
M__](C;W@[___N@`0``#H_??__XE%_(-]_`!Y#4C'A<C?__\`````ZU>+1?R#
MP`%(8_CH.?;__TB)1?!(@WWP`'4-2,>%R-___P````#K,8M%_$ACR$B+1?!(
MC970W___2(G'2(G6_/.DBT7\2)A(`T7PQ@``2(M%\$B)A<C?__](BX7(W___
MR<-52(GEZ!O____)PU5(B>5(@>S@$```2(F]2.___TB)M4#O__^_D7I``+@`
M````Z*/[__](B47X2(LU*:T@`$B+O4CO___H'??__TB%P'0I2(NU2.___[^:
M>D``N`````#HD?O__TB+A4CO__](B84X[___Z?X!``!(BX5([___2,?!____
M_TB)A3#O__^X`````/Q(B[TP[___\JY(B<A(]]!(@^@!B47P2(LUOZP@`$B+
MO4#O___H>_?__TB)1>CI@@$``$B+1>@/M@"$P'4(2,=%Z*=Z0`!(@WWX`'0K
M2(MUZ$B+??CH._?__X7`=1I(BS5XK"``OP````#H-O?__TB)1>CI/0$``$B+
M1>A(Q\'_____2(F%*.___[@`````_$B+O2CO___RKDB)R$CWT$B#Z`&)1?3K
M$(-M]`&+1?1(F$@#1>C&``"+1?1(F$@#1>A(@^@!#[802(L%!JP@``^V`#C"
M=-*+1?`#1?0]_@\``'XI2(NU2.___[^:>D``N`````#H:_K__TB+A4CO__](
MB84X[___Z=@```!(BPW"JR``2(N%2.___TB+5>A(C;W@[___28G`OJEZ0`"X
M`````.A.]?__2(VU4.___TB-O>#O___H*TT``(7`=5*+A6CO__\E`/```#T`
M@```=4!(C;W@[___O@$```#HQ/;__X7`=2M(C;7@[___OYIZ0`"X`````.C9
M^?__2(V]X.___^C>]?__2(F%..___^M$2(LU-JL@`+\`````Z/3U__](B47H
M2(-]Z``/A7/^__](B[5([___OYIZ0`"X`````.B.^?__2(N]2.___TB)O3CO
M__](BX4X[___R<-52(GE2(E]Z$B+1>A(B47P2(M%Z$B)1?CK)DB+1?@/MA!(
MBP7`JB``#[8`.,)U#$B+1?A(@\`!2(E%\$B#1?@!2(M%^`^V`(3`=<](BT7P
MR<-52(GE2(/L($B)??A(@WWX`'0+2(M%^`^V`(3`=1._IWI``.@/]?__2(E%
MZ.DZ`0``2(M%^$C'P?____](B47@N`````#\2(M]X/*N2(G(2/?02(/H`4@#
M1?A(@^@!2(E%\.L%2(-M\`%(BT7P2#M%^'8<2(M5\`^V`DB+%1:J(``/MA(X
MT'3<ZP5(@VWP`4B+3?!(.TWX=A5(BWWP#[8'2(L5\*D@``^V$CC0==Q(BT7P
M2#M%^'4Z2(M5\`^V`DB+%=&I(``/MA(XT'43OZ=Z0`#H8/3__TB)1>CIBP``
M`$B+/;"I(`#H2_3__TB)1>CK>4B#;?`!2(M-\$@[3?AV%4B+??`/M@=(BQ6(
MJ2``#[82.-!TW$B+5?!(BT7X2(G12"G!2(G(2(/``D@]`!```'8*2,=%Z```
M``#K+DB+5?!(BT7X2(G72"G'2(GX2(/``4B)PDB+=?B_`-E@`.@D]/__2,=%
MZ`#98`!(BT7HR<-52(GE2(/L,$B+!5=,``!(B4702(L%5$P``$B)1=A(BP51
M3```2(E%X$B+!4Y,``!(B47H#[<%2TP``&:)1?"_L'I``+@`````Z"_Z__^_
MP'I``+@`````Z"#Z__^_D7I``+@`````Z!'Z__^_S'I``+@`````Z`+Z__^_
MUGI``+@`````Z//Y__^_X'I``+@`````Z.3Y__^_FGI``+@`````Z-7Y__^_
MZGI``+@`````Z,;Y__^_\WI``+@`````Z+?Y__^__GI``+@`````Z,#V__](
MB47X2(-]^`!T$TB+=?B_UGI``+@`````Z,+V__^_#WM``+@`````Z)/V__](
MB47X2(-]^`!T$TB+=?B_(7M``+@`````Z)7V__^_+'M``+@`````Z&;V__](
MB47X2(-]^`!T%4B+=?B_D7I``+@`````Z&CV___K:;\\>T``N`````#H-_;_
M_TB)1?A(@WWX`'052(MU^+_,>D``N`````#H.?;__^LZ2(U%T$B#P!%(B47X
M2(M]^+H*````ODU[0`#H^>___X7`=1=(BW7X2(/&"K_,>D``N`````#H_?7_
M_[Y8>T``O[!Z0`"X`````.CI]?__R<-52(GE2(/L((L%6J<@`(/X_W5)O\QZ
M0`"X`````.BE]?__2(E%^$B#??@`=!](BT7X#[8`A,!T%$B+1?@/M@`\,'0)
MQT7L`0```.L'QT7L`````(M%[(D%#*<@`(L%!J<@`,G#54B)Y4B![&@"``!(
MB;TH_?__2(N%*/W__TB#P#A(B47`QT6\`````.FZ````2(M%P$B+`$B)1<A(
M@T7`"(M-O$B+1<A(P>`82(G"@>(```#_2(M%R$C!X`@E``#_`$@)PDB+1<A(
MP>@()0#_``!("<)(BT7(2,'H&"7_````2`G"2&/!2(F4Q3#]__](P6W(((M-
MO(/!`4B+1<A(P>`82(G"@>(```#_2(M%R$C!X`@E``#_`$@)PDB+1<A(P>@(
M)0#_``!("<)(BT7(2,'H&"7_````2`G"2&/!2(F4Q3#]__^#1;P"@WV\#P^.
M//___\=%O!````#IE````(M-O(M%O(/H`TB82(N4Q3#]__^+1;R#Z`A(F$B+
MA,4P_?__2#'"BT6\@^@.2)A(BX3%,/W__T@QPHM%O(/H$$B82(N$Q3#]__](
M,<)(8\%(B93%,/W__XM-O(M%O$B82(N$Q3#]__](C10`BT6\2)A(BX3%,/W_
M_TC!Z!]("=!(B<*#XO](8\%(B93%,/W__X-%O`&#?;Q/#XYB____2(N%*/W_
M_TB+`$B)1=!(BX4H_?__2(M`"$B)1=A(BX4H_?__2(M`$$B)1>!(BX4H_?__
M2(M`&$B)1>A(BX4H_?__2(M`($B)1?!(C84P_?__2(E%^$B+1=!(B<)(P>(%
M2(M%T$C!Z!M("=!(B<&#X?](BT7@2(M5V$@APDB+1=A(]]!((T7H2`G02(T$
M`4B)PD@#5?!(BT7X2(L`2(T$`D@%F7F"6H/@_TB)1<A(@T7X"$B+1=A(B<)(
MP>(>2(M%V$C!Z`)("="#X/](B4782(M%R$B)PDC!X@5(BT7(2,'H&T@)T$B)
MP8/A_TB+1=A(BU702"'"2(M%T$CWT$@C1>!("=!(C00!2(G"2`-5Z$B+1?A(
MBP!(C00"2`69>8):@^#_2(E%\$B#1?@(2(M%T$B)PDC!XAY(BT702,'H`D@)
MT(/@_TB)1=!(BT7P2(G"2,'B!4B+1?!(P>@;2`G02(G!@^'_2(M%T$B+5<A(
M(<)(BT7(2/?02"-%V$@)T$B-!`%(B<)(`U7@2(M%^$B+`$B-!`)(!9EY@EJ#
MX/](B47H2(-%^`A(BT7(2(G"2,'B'DB+1<A(P>@"2`G0@^#_2(E%R$B+1>A(
MB<)(P>(%2(M%Z$C!Z!M("=!(B<&#X?](BT7(2(M5\$@APDB+1?!(]]!((T70
M2`G02(T$`4B)PD@#5=A(BT7X2(L`2(T$`D@%F7F"6H/@_TB)1>!(@T7X"$B+
M1?!(B<)(P>(>2(M%\$C!Z`)("="#X/](B47P2(M%X$B)PDC!X@5(BT7@2,'H
M&T@)T$B)P8/A_TB+1?!(BU7H2"'"2(M%Z$CWT$@C1<A("=!(C00!2(G"2`-5
MT$B+1?A(BP!(C00"2`69>8):@^#_2(E%V$B#1?@(2(M%Z$B)PDC!XAY(BT7H
M2,'H`D@)T(/@_TB)1>A(BT782(G"2,'B!4B+1=A(P>@;2`G02(G!@^'_2(M%
MZ$B+5>!((<)(BT7@2/?02"-%\$@)T$B-!`%(B<)(`U7(2(M%^$B+`$B-!`)(
M!9EY@EJ#X/](B4702(-%^`A(BT7@2(G"2,'B'DB+1>!(P>@"2`G0@^#_2(E%
MX$B+1=!(B<)(P>(%2(M%T$C!Z!M("=!(B<&#X?](BT7@2(M5V$@APDB+1=A(
M]]!((T7H2`G02(T$`4B)PD@#5?!(BT7X2(L`2(T$`D@%F7F"6H/@_TB)1<A(
M@T7X"$B+1=A(B<)(P>(>2(M%V$C!Z`)("="#X/](B4782(M%R$B)PDC!X@5(
MBT7(2,'H&T@)T$B)P8/A_TB+1=A(BU702"'"2(M%T$CWT$@C1>!("=!(C00!
M2(G"2`-5Z$B+1?A(BP!(C00"2`69>8):@^#_2(E%\$B#1?@(2(M%T$B)PDC!
MXAY(BT702,'H`D@)T(/@_TB)1=!(BT7P2(G"2,'B!4B+1?!(P>@;2`G02(G!
M@^'_2(M%T$B+5<A((<)(BT7(2/?02"-%V$@)T$B-!`%(B<)(`U7@2(M%^$B+
M`$B-!`)(!9EY@EJ#X/](B47H2(-%^`A(BT7(2(G"2,'B'DB+1<A(P>@"2`G0
M@^#_2(E%R$B+1>A(B<)(P>(%2(M%Z$C!Z!M("=!(B<&#X?](BT7(2(M5\$@A
MPDB+1?!(]]!((T702`G02(T$`4B)PD@#5=A(BT7X2(L`2(T$`D@%F7F"6H/@
M_TB)1>!(@T7X"$B+1?!(B<)(P>(>2(M%\$C!Z`)("="#X/](B47P2(M%X$B)
MPDC!X@5(BT7@2,'H&T@)T$B)P8/A_TB+1?!(BU7H2"'"2(M%Z$CWT$@C1<A(
M"=!(C00!2(G"2`-5T$B+1?A(BP!(C00"2`69>8):@^#_2(E%V$B#1?@(2(M%
MZ$B)PDC!XAY(BT7H2,'H`D@)T(/@_TB)1>A(BT782(G"2,'B!4B+1=A(P>@;
M2`G02(G!@^'_2(M%Z$B+5>!((<)(BT7@2/?02"-%\$@)T$B-!`%(B<)(`U7(
M2(M%^$B+`$B-!`)(!9EY@EJ#X/](B4702(-%^`A(BT7@2(G"2,'B'DB+1>!(
MP>@"2`G0@^#_2(E%X$B+1=!(B<)(P>(%2(M%T$C!Z!M("=!(B<&#X?](BT7@
M2(M5V$@APDB+1=A(]]!((T7H2`G02(T$`4B)PD@#5?!(BT7X2(L`2(T$`D@%
MF7F"6H/@_TB)1<A(@T7X"$B+1=A(B<)(P>(>2(M%V$C!Z`)("="#X/](B478
M2(M%R$B)PDC!X@5(BT7(2,'H&T@)T$B)P8/A_TB+1=A(BU702"'"2(M%T$CW
MT$@C1>!("=!(C00!2(G"2`-5Z$B+1?A(BP!(C00"2`69>8):@^#_2(E%\$B#
M1?@(2(M%T$B)PDC!XAY(BT702,'H`D@)T(/@_TB)1=!(BT7P2(G"2,'B!4B+
M1?!(P>@;2`G02(G!@^'_2(M%T$B+5<A((<)(BT7(2/?02"-%V$@)T$B-!`%(
MB<)(`U7@2(M%^$B+`$B-!`)(!9EY@EJ#X/](B47H2(-%^`A(BT7(2(G"2,'B
M'DB+1<A(P>@"2`G0@^#_2(E%R$B+1>A(B<)(P>(%2(M%Z$C!Z!M("=!(B<&#
MX?](BT7(2(M5\$@APDB+1?!(]]!((T702`G02(T$`4B)PD@#5=A(BT7X2(L`
M2(T$`D@%F7F"6H/@_TB)1>!(@T7X"$B+1?!(B<)(P>(>2(M%\$C!Z`)("="#
MX/](B47P2(M%X$B)PDC!X@5(BT7@2,'H&T@)T$B)P8/A_TB+1?!(BU7H2"'"
M2(M%Z$CWT$@C1<A("=!(C00!2(G"2`-5T$B+1?A(BP!(C00"2`69>8):@^#_
M2(E%V$B#1?@(2(M%Z$B)PDC!XAY(BT7H2,'H`D@)T(/@_TB)1>A(BT782(G"
M2,'B!4B+1=A(P>@;2`G02(G!@^'_2(M%Z$B+5>!((<)(BT7@2/?02"-%\$@)
MT$B-!`%(B<)(`U7(2(M%^$B+`$B-!`)(!9EY@EJ#X/](B4702(-%^`A(BT7@
M2(G"2,'B'DB+1>!(P>@"2`G0@^#_2(E%X$B+1=!(B<)(P>(%2(M%T$C!Z!M(
M"=!(B<&#X?](BT7@2(M5V$@APDB+1=A(]]!((T7H2`G02(T$`4B)PD@#5?!(
MBT7X2(L`2(T$`D@%F7F"6H/@_TB)1<A(@T7X"$B+1=A(B<)(P>(>2(M%V$C!
MZ`)("="#X/](B4782(M%R$B)PDC!X@5(BT7(2,'H&T@)T$B)P8/A_TB+1=A(
MBU702"'"2(M%T$CWT$@C1>!("=!(C00!2(G"2`-5Z$B+1?A(BP!(C00"2`69
M>8):@^#_2(E%\$B#1?@(2(M%T$B)PDC!XAY(BT702,'H`D@)T(/@_TB)1=!(
MBT7P2(G"2,'B!4B+1?!(P>@;2`G02(G"@^+_2(M%T$@S1<A(,T782(T$`DB)
MPD@#5>!(BT7X2(L`2(T$`D@%H>O9;H/@_TB)1>A(@T7X"$B+1<A(B<)(P>(>
M2(M%R$C!Z`)("="#X/](B47(2(M%Z$B)PDC!X@5(BT7H2,'H&T@)T$B)PH/B
M_TB+1<A(,T7P2#-%T$B-!`)(B<)(`U782(M%^$B+`$B-!`)(!:'KV6Z#X/](
MB47@2(-%^`A(BT7P2(G"2,'B'DB+1?!(P>@"2`G0@^#_2(E%\$B+1>!(B<)(
MP>(%2(M%X$C!Z!M("=!(B<*#XO](BT7P2#-%Z$@S1<A(C00"2(G"2`-5T$B+
M1?A(BP!(C00"2`6AZ]EN@^#_2(E%V$B#1?@(2(M%Z$B)PDC!XAY(BT7H2,'H
M`D@)T(/@_TB)1>A(BT782(G"2,'B!4B+1=A(P>@;2`G02(G"@^+_2(M%Z$@S
M1>!(,T7P2(T$`DB)PD@#5<A(BT7X2(L`2(T$`D@%H>O9;H/@_TB)1=!(@T7X
M"$B+1>!(B<)(P>(>2(M%X$C!Z`)("="#X/](B47@2(M%T$B)PDC!X@5(BT70
M2,'H&T@)T$B)PH/B_TB+1>!(,T782#-%Z$B-!`)(B<)(`U7P2(M%^$B+`$B-
M!`)(!:'KV6Z#X/](B47(2(-%^`A(BT782(G"2,'B'DB+1=A(P>@"2`G0@^#_
M2(E%V$B+1<A(B<)(P>(%2(M%R$C!Z!M("=!(B<*#XO](BT782#-%T$@S1>!(
MC00"2(G"2`-5Z$B+1?A(BP!(C00"2`6AZ]EN@^#_2(E%\$B#1?@(2(M%T$B)
MPDC!XAY(BT702,'H`D@)T(/@_TB)1=!(BT7P2(G"2,'B!4B+1?!(P>@;2`G0
M2(G"@^+_2(M%T$@S1<A(,T782(T$`DB)PD@#5>!(BT7X2(L`2(T$`D@%H>O9
M;H/@_TB)1>A(@T7X"$B+1<A(B<)(P>(>2(M%R$C!Z`)("="#X/](B47(2(M%
MZ$B)PDC!X@5(BT7H2,'H&T@)T$B)PH/B_TB+1<A(,T7P2#-%T$B-!`)(B<)(
M`U782(M%^$B+`$B-!`)(!:'KV6Z#X/](B47@2(-%^`A(BT7P2(G"2,'B'DB+
M1?!(P>@"2`G0@^#_2(E%\$B+1>!(B<)(P>(%2(M%X$C!Z!M("=!(B<*#XO](
MBT7P2#-%Z$@S1<A(C00"2(G"2`-5T$B+1?A(BP!(C00"2`6AZ]EN@^#_2(E%
MV$B#1?@(2(M%Z$B)PDC!XAY(BT7H2,'H`D@)T(/@_TB)1>A(BT782(G"2,'B
M!4B+1=A(P>@;2`G02(G"@^+_2(M%Z$@S1>!(,T7P2(T$`DB)PD@#5<A(BT7X
M2(L`2(T$`D@%H>O9;H/@_TB)1=!(@T7X"$B+1>!(B<)(P>(>2(M%X$C!Z`)(
M"="#X/](B47@2(M%T$B)PDC!X@5(BT702,'H&T@)T$B)PH/B_TB+1>!(,T78
M2#-%Z$B-!`)(B<)(`U7P2(M%^$B+`$B-!`)(!:'KV6Z#X/](B47(2(-%^`A(
MBT782(G"2,'B'DB+1=A(P>@"2`G0@^#_2(E%V$B+1<A(B<)(P>(%2(M%R$C!
MZ!M("=!(B<*#XO](BT782#-%T$@S1>!(C00"2(G"2`-5Z$B+1?A(BP!(C00"
M2`6AZ]EN@^#_2(E%\$B#1?@(2(M%T$B)PDC!XAY(BT702,'H`D@)T(/@_TB)
M1=!(BT7P2(G"2,'B!4B+1?!(P>@;2`G02(G"@^+_2(M%T$@S1<A(,T782(T$
M`DB)PD@#5>!(BT7X2(L`2(T$`D@%H>O9;H/@_TB)1>A(@T7X"$B+1<A(B<)(
MP>(>2(M%R$C!Z`)("="#X/](B47(2(M%Z$B)PDC!X@5(BT7H2,'H&T@)T$B)
MPH/B_TB+1<A(,T7P2#-%T$B-!`)(B<)(`U782(M%^$B+`$B-!`)(!:'KV6Z#
MX/](B47@2(-%^`A(BT7P2(G"2,'B'DB+1?!(P>@"2`G0@^#_2(E%\$B+1>!(
MB<)(P>(%2(M%X$C!Z!M("=!(B<*#XO](BT7P2#-%Z$@S1<A(C00"2(G"2`-5
MT$B+1?A(BP!(C00"2`6AZ]EN@^#_2(E%V$B#1?@(2(M%Z$B)PDC!XAY(BT7H
M2,'H`D@)T(/@_TB)1>A(BT782(G"2,'B!4B+1=A(P>@;2`G02(G"@^+_2(M%
MZ$@S1>!(,T7P2(T$`DB)PD@#5<A(BT7X2(L`2(T$`D@%H>O9;H/@_TB)1=!(
M@T7X"$B+1>!(B<)(P>(>2(M%X$C!Z`)("="#X/](B47@2(M%T$B)PDC!X@5(
MBT702,'H&T@)T$B)PH/B_TB+1>!(,T782#-%Z$B-!`)(B<)(`U7P2(M%^$B+
M`$B-!`)(!:'KV6Z#X/](B47(2(-%^`A(BT782(G"2,'B'DB+1=A(P>@"2`G0
M@^#_2(E%V$B+1<A(B<)(P>(%2(M%R$C!Z!M("=!(B<*#XO](BT782#-%T$@S
M1>!(C00"2(G"2`-5Z$B+1?A(BP!(C00"2`6AZ]EN@^#_2(E%\$B#1?@(2(M%
MT$B)PDC!XAY(BT702,'H`D@)T(/@_TB)1=!(BT7P2(G"2,'B!4B+1?!(P>@;
M2`G02(G"@^+_2(M%T$@S1<A(,T782(T$`DB)PD@#5>!(BT7X2(L`2(T$`D@%
MH>O9;H/@_TB)1>A(@T7X"$B+1<A(B<)(P>(>2(M%R$C!Z`)("="#X/](B47(
M2(M%Z$B)PDC!X@5(BT7H2,'H&T@)T$B)PH/B_TB+1<A(,T7P2#-%T$B-!`)(
MB<)(`U782(M%^$B+`$B-!`)(!:'KV6Z#X/](B47@2(-%^`A(BT7P2(G"2,'B
M'DB+1?!(P>@"2`G0@^#_2(E%\$B+1>!(B<)(P>(%2(M%X$C!Z!M("=!(B<&#
MX?](BT7(2`M%\$B)PD@C5>A(BT7(2"-%\$@)T$B-!`%(B<)(`U702(M%^$B+
M`$@!PKC<O!N/2(T$`H/@_TB)1=A(@T7X"$B+1>A(B<)(P>(>2(M%Z$C!Z`)(
M"="#X/](B47H2(M%V$B)PDC!X@5(BT782,'H&T@)T$B)P8/A_TB+1?!("T7H
M2(G"2"-5X$B+1?!((T7H2`G02(T$`4B)PD@#5<A(BT7X2(L`2`'"N-R\&X](
MC00"@^#_2(E%T$B#1?@(2(M%X$B)PDC!XAY(BT7@2,'H`D@)T(/@_TB)1>!(
MBT702(G"2,'B!4B+1=!(P>@;2`G02(G!@^'_2(M%Z$@+1>!(B<)((U782(M%
MZ$@C1>!("=!(C00!2(G"2`-5\$B+1?A(BP!(`<*XW+P;CTB-!`*#X/](B47(
M2(-%^`A(BT782(G"2,'B'DB+1=A(P>@"2`G0@^#_2(E%V$B+1<A(B<)(P>(%
M2(M%R$C!Z!M("=!(B<&#X?](BT7@2`M%V$B)PD@C5=!(BT7@2"-%V$@)T$B-
M!`%(B<)(`U7H2(M%^$B+`$@!PKC<O!N/2(T$`H/@_TB)1?!(@T7X"$B+1=!(
MB<)(P>(>2(M%T$C!Z`)("="#X/](B4702(M%\$B)PDC!X@5(BT7P2,'H&T@)
MT$B)P8/A_TB+1=A("T702(G"2"-5R$B+1=A((T702`G02(T$`4B)PD@#5>!(
MBT7X2(L`2`'"N-R\&X](C00"@^#_2(E%Z$B#1?@(2(M%R$B)PDC!XAY(BT7(
M2,'H`D@)T(/@_TB)1<A(BT7H2(G"2,'B!4B+1>A(P>@;2`G02(G!@^'_2(M%
MT$@+1<A(B<)((U7P2(M%T$@C1<A("=!(C00!2(G"2`-5V$B+1?A(BP!(`<*X
MW+P;CTB-!`*#X/](B47@2(-%^`A(BT7P2(G"2,'B'DB+1?!(P>@"2`G0@^#_
M2(E%\$B+1>!(B<)(P>(%2(M%X$C!Z!M("=!(B<&#X?](BT7(2`M%\$B)PD@C
M5>A(BT7(2"-%\$@)T$B-!`%(B<)(`U702(M%^$B+`$@!PKC<O!N/2(T$`H/@
M_TB)1=A(@T7X"$B+1>A(B<)(P>(>2(M%Z$C!Z`)("="#X/](B47H2(M%V$B)
MPDC!X@5(BT782,'H&T@)T$B)P8/A_TB+1?!("T7H2(G"2"-5X$B+1?!((T7H
M2`G02(T$`4B)PD@#5<A(BT7X2(L`2`'"N-R\&X](C00"@^#_2(E%T$B#1?@(
M2(M%X$B)PDC!XAY(BT7@2,'H`D@)T(/@_TB)1>!(BT702(G"2,'B!4B+1=!(
MP>@;2`G02(G!@^'_2(M%Z$@+1>!(B<)((U782(M%Z$@C1>!("=!(C00!2(G"
M2`-5\$B+1?A(BP!(`<*XW+P;CTB-!`*#X/](B47(2(-%^`A(BT782(G"2,'B
M'DB+1=A(P>@"2`G0@^#_2(E%V$B+1<A(B<)(P>(%2(M%R$C!Z!M("=!(B<&#
MX?](BT7@2`M%V$B)PD@C5=!(BT7@2"-%V$@)T$B-!`%(B<)(`U7H2(M%^$B+
M`$@!PKC<O!N/2(T$`H/@_TB)1?!(@T7X"$B+1=!(B<)(P>(>2(M%T$C!Z`)(
M"="#X/](B4702(M%\$B)PDC!X@5(BT7P2,'H&T@)T$B)P8/A_TB+1=A("T70
M2(G"2"-5R$B+1=A((T702`G02(T$`4B)PD@#5>!(BT7X2(L`2`'"N-R\&X](
MC00"@^#_2(E%Z$B#1?@(2(M%R$B)PDC!XAY(BT7(2,'H`D@)T(/@_TB)1<A(
MBT7H2(G"2,'B!4B+1>A(P>@;2`G02(G!@^'_2(M%T$@+1<A(B<)((U7P2(M%
MT$@C1<A("=!(C00!2(G"2`-5V$B+1?A(BP!(`<*XW+P;CTB-!`*#X/](B47@
M2(-%^`A(BT7P2(G"2,'B'DB+1?!(P>@"2`G0@^#_2(E%\$B+1>!(B<)(P>(%
M2(M%X$C!Z!M("=!(B<&#X?](BT7(2`M%\$B)PD@C5>A(BT7(2"-%\$@)T$B-
M!`%(B<)(`U702(M%^$B+`$@!PKC<O!N/2(T$`H/@_TB)1=A(@T7X"$B+1>A(
MB<)(P>(>2(M%Z$C!Z`)("="#X/](B47H2(M%V$B)PDC!X@5(BT782,'H&T@)
MT$B)P8/A_TB+1?!("T7H2(G"2"-5X$B+1?!((T7H2`G02(T$`4B)PD@#5<A(
MBT7X2(L`2`'"N-R\&X](C00"@^#_2(E%T$B#1?@(2(M%X$B)PDC!XAY(BT7@
M2,'H`D@)T(/@_TB)1>!(BT702(G"2,'B!4B+1=!(P>@;2`G02(G!@^'_2(M%
MZ$@+1>!(B<)((U782(M%Z$@C1>!("=!(C00!2(G"2`-5\$B+1?A(BP!(`<*X
MW+P;CTB-!`*#X/](B47(2(-%^`A(BT782(G"2,'B'DB+1=A(P>@"2`G0@^#_
M2(E%V$B+1<A(B<)(P>(%2(M%R$C!Z!M("=!(B<&#X?](BT7@2`M%V$B)PD@C
M5=!(BT7@2"-%V$@)T$B-!`%(B<)(`U7H2(M%^$B+`$@!PKC<O!N/2(T$`H/@
M_TB)1?!(@T7X"$B+1=!(B<)(P>(>2(M%T$C!Z`)("="#X/](B4702(M%\$B)
MPDC!X@5(BT7P2,'H&T@)T$B)P8/A_TB+1=A("T702(G"2"-5R$B+1=A((T70
M2`G02(T$`4B)PD@#5>!(BT7X2(L`2`'"N-R\&X](C00"@^#_2(E%Z$B#1?@(
M2(M%R$B)PDC!XAY(BT7(2,'H`D@)T(/@_TB)1<A(BT7H2(G"2,'B!4B+1>A(
MP>@;2`G02(G!@^'_2(M%T$@+1<A(B<)((U7P2(M%T$@C1<A("=!(C00!2(G"
M2`-5V$B+1?A(BP!(`<*XW+P;CTB-!`*#X/](B47@2(-%^`A(BT7P2(G"2,'B
M'DB+1?!(P>@"2`G0@^#_2(E%\$B+1>!(B<)(P>(%2(M%X$C!Z!M("=!(B<&#
MX?](BT7(2`M%\$B)PD@C5>A(BT7(2"-%\$@)T$B-!`%(B<)(`U702(M%^$B+
M`$@!PKC<O!N/2(T$`H/@_TB)1=A(@T7X"$B+1>A(B<)(P>(>2(M%Z$C!Z`)(
M"="#X/](B47H2(M%V$B)PDC!X@5(BT782,'H&T@)T$B)P8/A_TB+1?!("T7H
M2(G"2"-5X$B+1?!((T7H2`G02(T$`4B)PD@#5<A(BT7X2(L`2`'"N-R\&X](
MC00"@^#_2(E%T$B#1?@(2(M%X$B)PDC!XAY(BT7@2,'H`D@)T(/@_TB)1>!(
MBT702(G"2,'B!4B+1=!(P>@;2`G02(G"@^+_2(M%X$@S1=A(,T7H2(T$`DB)
MPD@#5?!(BT7X2(L`2`'"N-;!8LI(C00"@^#_2(E%R$B#1?@(2(M%V$B)PDC!
MXAY(BT782,'H`D@)T(/@_TB)1=A(BT7(2(G"2,'B!4B+1<A(P>@;2`G02(G"
M@^+_2(M%V$@S1=!(,T7@2(T$`DB)PD@#5>A(BT7X2(L`2`'"N-;!8LI(C00"
M@^#_2(E%\$B#1?@(2(M%T$B)PDC!XAY(BT702,'H`D@)T(/@_TB)1=!(BT7P
M2(G"2,'B!4B+1?!(P>@;2`G02(G"@^+_2(M%T$@S1<A(,T782(T$`DB)PD@#
M5>!(BT7X2(L`2`'"N-;!8LI(C00"@^#_2(E%Z$B#1?@(2(M%R$B)PDC!XAY(
MBT7(2,'H`D@)T(/@_TB)1<A(BT7H2(G"2,'B!4B+1>A(P>@;2`G02(G"@^+_
M2(M%R$@S1?!(,T702(T$`DB)PD@#5=A(BT7X2(L`2`'"N-;!8LI(C00"@^#_
M2(E%X$B#1?@(2(M%\$B)PDC!XAY(BT7P2,'H`D@)T(/@_TB)1?!(BT7@2(G"
M2,'B!4B+1>!(P>@;2`G02(G"@^+_2(M%\$@S1>A(,T7(2(T$`DB)PD@#5=!(
MBT7X2(L`2`'"N-;!8LI(C00"@^#_2(E%V$B#1?@(2(M%Z$B)PDC!XAY(BT7H
M2,'H`D@)T(/@_TB)1>A(BT782(G"2,'B!4B+1=A(P>@;2`G02(G"@^+_2(M%
MZ$@S1>!(,T7P2(T$`DB)PD@#5<A(BT7X2(L`2`'"N-;!8LI(C00"@^#_2(E%
MT$B#1?@(2(M%X$B)PDC!XAY(BT7@2,'H`D@)T(/@_TB)1>!(BT702(G"2,'B
M!4B+1=!(P>@;2`G02(G"@^+_2(M%X$@S1=A(,T7H2(T$`DB)PD@#5?!(BT7X
M2(L`2`'"N-;!8LI(C00"@^#_2(E%R$B#1?@(2(M%V$B)PDC!XAY(BT782,'H
M`D@)T(/@_TB)1=A(BT7(2(G"2,'B!4B+1<A(P>@;2`G02(G"@^+_2(M%V$@S
M1=!(,T7@2(T$`DB)PD@#5>A(BT7X2(L`2`'"N-;!8LI(C00"@^#_2(E%\$B#
M1?@(2(M%T$B)PDC!XAY(BT702,'H`D@)T(/@_TB)1=!(BT7P2(G"2,'B!4B+
M1?!(P>@;2`G02(G"@^+_2(M%T$@S1<A(,T782(T$`DB)PD@#5>!(BT7X2(L`
M2`'"N-;!8LI(C00"@^#_2(E%Z$B#1?@(2(M%R$B)PDC!XAY(BT7(2,'H`D@)
MT(/@_TB)1<A(BT7H2(G"2,'B!4B+1>A(P>@;2`G02(G"@^+_2(M%R$@S1?!(
M,T702(T$`DB)PD@#5=A(BT7X2(L`2`'"N-;!8LI(C00"@^#_2(E%X$B#1?@(
M2(M%\$B)PDC!XAY(BT7P2,'H`D@)T(/@_TB)1?!(BT7@2(G"2,'B!4B+1>!(
MP>@;2`G02(G"@^+_2(M%\$@S1>A(,T7(2(T$`DB)PD@#5=!(BT7X2(L`2`'"
MN-;!8LI(C00"@^#_2(E%V$B#1?@(2(M%Z$B)PDC!XAY(BT7H2,'H`D@)T(/@
M_TB)1>A(BT782(G"2,'B!4B+1=A(P>@;2`G02(G"@^+_2(M%Z$@S1>!(,T7P
M2(T$`DB)PD@#5<A(BT7X2(L`2`'"N-;!8LI(C00"@^#_2(E%T$B#1?@(2(M%
MX$B)PDC!XAY(BT7@2,'H`D@)T(/@_TB)1>!(BT702(G"2,'B!4B+1=!(P>@;
M2`G02(G"@^+_2(M%X$@S1=A(,T7H2(T$`DB)PD@#5?!(BT7X2(L`2`'"N-;!
M8LI(C00"@^#_2(E%R$B#1?@(2(M%V$B)PDC!XAY(BT782,'H`D@)T(/@_TB)
M1=A(BT7(2(G"2,'B!4B+1<A(P>@;2`G02(G"@^+_2(M%V$@S1=!(,T7@2(T$
M`DB)PD@#5>A(BT7X2(L`2`'"N-;!8LI(C00"@^#_2(E%\$B#1?@(2(M%T$B)
MPDC!XAY(BT702,'H`D@)T(/@_TB)1=!(BT7P2(G"2,'B!4B+1?!(P>@;2`G0
M2(G"@^+_2(M%T$@S1<A(,T782(T$`DB)PD@#5>!(BT7X2(L`2`'"N-;!8LI(
MC00"@^#_2(E%Z$B#1?@(2(M%R$B)PDC!XAY(BT7(2,'H`D@)T(/@_TB)1<A(
MBT7H2(G"2,'B!4B+1>A(P>@;2`G02(G"@^+_2(M%R$@S1?!(,T702(T$`DB)
MPD@#5=A(BT7X2(L`2`'"N-;!8LI(C00"@^#_2(E%X$B#1?@(2(M%\$B)PDC!
MXAY(BT7P2,'H`D@)T(/@_TB)1?!(BT7@2(G"2,'B!4B+1>!(P>@;2`G02(G"
M@^+_2(M%\$@S1>A(,T7(2(T$`DB)PD@#5=!(BT7X2(L`2`'"N-;!8LI(C00"
M@^#_2(E%V$B#1?@(2(M%Z$B)PDC!XAY(BT7H2,'H`D@)T(/@_TB)1>A(BT78
M2(G"2,'B!4B+1=A(P>@;2`G02(G"@^+_2(M%Z$@S1>!(,T7P2(T$`DB)PD@#
M5<A(BT7X2(L`2`'"N-;!8LI(C00"@^#_2(E%T$B#1?@(2(M%X$B)PDC!XAY(
MBT7@2,'H`D@)T(/@_TB)1>!(BT702(G"2,'B!4B+1=!(P>@;2`G02(G"@^+_
M2(M%X$@S1=A(,T7H2(T$`DB)PD@#5?!(BT7X2(L`2`'"N-;!8LI(C00"@^#_
M2(E%R$B#1?@(2(M%V$B)PDC!XAY(BT782,'H`D@)T(/@_TB)1=A(BT7(2(G"
M2,'B!4B+1<A(P>@;2`G02(G"@^+_2(M%V$@S1=!(,T7@2(T$`DB)PD@#5>A(
MBT7X2(L`2`'"N-;!8LI(C00"@^#_2(E%\$B#1?@(2(M%T$B)PDC!XAY(BT70
M2,'H`D@)T(/@_TB)1=!(BX4H_?__2(L`2`-%\$B)PH/B_TB+A2C]__](B1!(
MBX4H_?__2(M`"$@#1<A(B<*#XO](BX4H_?__2(E0"$B+A2C]__](BT`02`-%
MT$B)PH/B_TB+A2C]__](B5`02(N%*/W__TB+0!A(`T782(G"@^+_2(N%*/W_
M_TB)4!A(BX4H_?__2(M`($@#1>!(B<*#XO](BX4H_?__2(E0(,G#54B)Y4B)
M??A(BT7X2,<``2-%9TB+1?C'0`B)J\WOQT`,`````$B+1?C'0!#^W+J8QT`4
M`````$B+1?A(QT`8=E0R$$B+1?C'0"#PX=+#QT`D`````$B+1?A(QT`H````
M`$B+1?A(QT`P`````$B+1?C'0'@`````R<-52(GE2(/L,$B)?>A(B77@B57<
M2(M%Z$B+4"B+1=Q(F$C!X`-(C00"@^#_2(E%^$B+1>A(BT`H2#M%^'842(M%
MZ$B+0#!(C5`!2(M%Z$B)4#!(BU7H2(M%^$B)0BA(BT7H2(M0,(M%W$B82,'H
M'4@!PDB+1>A(B5`P2(M%Z(M`>(7`#X3@````2(M%Z(M0>+A`````*=")1?2+
M1?0[1=Q^!HM%W(E%](M%]$ACR$B+5>A(@\(X2(M%Z(M`>$B82(T$`DB+5>!(
MB<=(B=;\\Z2+1?0I1=R+1?1(F$@!1>!(BT7HBT!XB<(#5?1(BT7HB5!X2(M%
MZ(M`>(/X0`^%D@```$B+?>CH<-?__^M<2(M-Z$B#P3A(BU7@2(L"2(D!2(M"
M"$B)00A(BT(02(E!$$B+0AA(B4$82(M"($B)02!(BT(H2(E!*$B+0C!(B4$P
M2(M".$B)03A(@T7@0(-MW$!(BWWHZ!+7__^#?=P_?YZ+1=Q(8\A(BT7H2(/`
M.$B+5>!(B<=(B=;\\Z1(BU7HBT7<B4)XR<-52(GE2(/L$$B)??A(B77P2(M]
M\.C,UO__2(M%\$B+`$C!Z!B)PDB+1?B($$B+5?A(@\(!2(M%\$B+`$C!Z!"(
M`DB+5?A(@\("2(M%\$B+`$C!Z`B(`DB+5?A(@\(#2(M%\$B+`(@"2(M5^$B#
MP@1(BT7P2(M`"$C!Z!B(`DB+5?A(@\(%2(M%\$B+0`A(P>@0B`)(BU7X2(/"
M!DB+1?!(BT`(2,'H"(@"2(M5^$B#P@=(BT7P2(M`"(@"2(M5^$B#P@A(BT7P
M2(M`$$C!Z!B(`DB+5?A(@\()2(M%\$B+0!!(P>@0B`)(BU7X2(/""DB+1?!(
MBT`02,'H"(@"2(M5^$B#P@M(BT7P2(M`$(@"2(M5^$B#P@Q(BT7P2(M`&$C!
MZ!B(`DB+5?A(@\(-2(M%\$B+0!A(P>@0B`)(BU7X2(/"#DB+1?!(BT`82,'H
M"(@"2(M5^$B#P@](BT7P2(M`&(@"2(M5^$B#PA!(BT7P2(M`($C!Z!B(`DB+
M5?A(@\(12(M%\$B+0"!(P>@0B`)(BU7X2(/"$DB+1?!(BT`@2,'H"(@"2(M5
M^$B#PA-(BT7P2(M`((@"R<-52(GE2(/L,$B)?=A(B7702(M%T$B+0"A(B47P
M2(M%T$B+0#!(B47X2(M%\$C!Z`.#X#^)1>Q(BU702(/".(M%[$B82(T$`L8`
M@(-%[`&#?>PX?E"X0````"M%[$ACR$B+5=!(@\(XBT7L2)A(C00"2(G'_+@`
M````\ZI(BWW0Z*C4__](BT702(/`.$B)Q_RZ`````+@'````B<%(B=#S2*OK
M)[@X````*T7L2&/(2(M5T$B#PCB+1>Q(F$B-!`)(B<?\N`````#SJDB+1?A(
MP>@8B<)(BT70B%!P2(M%^$C!Z!")PDB+1="(4'%(BT7X2,'H"(G"2(M%T(A0
M<DB+1?B)PDB+1="(4'-(BT7P2,'H&(G"2(M%T(A0=$B+1?!(P>@0B<)(BT70
MB%!U2(M%\$C!Z`B)PDB+1="(4'9(BT7PB<)(BT70B%!W2(MUT$B+?=CH[_S_
M_\G#54B)Y4B#['!(B7VH2,=%X`````!(QT7H`````$C'1;"">T``2,=%N))[
M0`!(QT7`FGM``$C'1<BG>T``2,=%T*Q[0`!(QT78OGM``$C'1?@`````QT7T
M`````.D2`0``2(M]X+@`````Z,?(__](B47H2(-]Z`!T"TB+1>@/M@"$P'47
M2(MUJ$B+?>"X`````.B_R/__Z=,```!(BW6H2(M]Z.@>Q/__2(7`#X6]````
M2(M%J$C'P?____](B46@N`````#\2(M]H/*N2(G(2/?02(U0_TB+!?%Y(`!(
MQ\'_____2(E%F+@`````_$B+?9CRKDB)R$CWT$B#Z`%(`<)(BT7H2,?!____
M_TB)19"X`````/Q(BWV0\JY(B<A(]]!(@^@!2(T$`DB->`+H$\+__TB)1?A(
MBPV0>2``2(M%Z$B+5:A(BWWX28G`OJEZ0`"X`````.@:P___2(MU^$B+?>"X
M`````.CGQ___@T7T`8M%]$B82(M$Q;!(B47@2(M%X`^V`(3`#X71_O__R<-5
M2(GE2('L8((``$B)O<A]__](QT6P`````$C'1;@`````2,=%P`````!(QT6`
MOWM``$C'18C'>T``2,=%D*=Z0`!(QT68OGM``$C'A5#___\A>T``2,>%6/__
M_\Q[0`!(QX5@____TWM``$C'A6C____;>T``2,>%</___^![0`!(QX5X____
MOGM``$C'A3#____D>T``2,>%./___^E[0`!(QX5`____OGM``$C'1<CR>T``
M2,=%T+Y[0`!(QT78`````$C'1>``````2,=%Z`````#'1?P`````OY%Z0`"X
M`````.BYQO__2(E%P$B#?<``="E(BT7`#[8`A,!T'DB+?<#H9?W__TB+?<#H
MPL+__TB)A<!]___I=04``,=%I`````#K*DB+?;BX`````.ANQO__2(E%P$B#
M?<``=`U(BWW`Z(O"__](B47@@T6D`4B#?>``=1R+1:1(F$B+A,4P____2(E%
MN$B+1;@/M@"$P'6S2(-]X`!U"DC'1>#W>T``ZTA(BT7@2(E%J.LSZ"#!__](
MBQ!(BT6H#[8`2`^^P$@!P$B-!`(/MP`/M\"#X`B%P'4'2(M%J,8`7TB#1:@!
M2(M%J`^V`(3`=<+'1:0`````ZW1(BWVXN`````#HO\7__TB)1<!(@WW``'17
M2(VUT'W__TB+?<#HY1@``(7`=4.+A>A]__\E`/```#T`0```=!*+A>A]__\E
M`/```#T`H```=1](BWW`O@(```#H7\+__X7`=0U(BWW`Z)+!__](B46P@T6D
M`4B#?;``=2"+1:1(F$B+A,50____2(E%N$B+1;@/M@"$P`^%9?___\=%I```
M``#K6TB-M=!]__](BWW`Z%H8``"%P'5#BX7H??__)0#P```]`$```'02BX7H
M??__)0#P```]`*```'4?2(M]P+X"````Z-3!__^%P'4-2(M]P.@'P?__2(E%
ML(-%I`%(@WVP`'49BT6D2)A(BT3%@$B)1<!(BT7`#[8`A,!UA4B+1;!(Q\'_
M____2(F%N'W__[@`````_$B+O;A]___RKDB)R$CWT$B#Z`&)PDB+1<A(Q\'_
M____2(F%L'W__[@`````_$B+O;!]___RKDB)R$CWT$B#Z`$!PDB+1>!(Q\'_
M____2(F%J'W__[@`````_$B+O:A]___RKDB)R$CWT$B#Z`$!PDB+1=!(Q\'_
M____2(F%H'W__[@`````_$B+O:!]___RKDB)R$CWT$B#Z`&-!`(%``0``(E%
M_(M%_$AC^.CWO?__2(E%Z$B+#6QU(`!(BT7@2(M5R$B+=;!(BWWH28G!28G0
M2(GROOY[0`"X`````.CTOO__2(M]Z+[M`0``Z`;!__^_IWM``+@`````Z);#
M__](B47`2(M]P.BZO___2(G&2(N%R'W__TB+..BLQ___2(E%V$B#?=@`=0Y(
MBX7(??__2(L`2(E%V+@`````Z(W-__^%P`^%SP$``$B+?=B^`````+@`````
MZ+J^__^)1?"#??``#X2O`0``BWWPN@(```!(Q\;N____Z,F___](C;6`?O__
MBWWPN@8```#H];S__P^VA8!^__^$P`^%G@````^VA8%^__\\0P^%CP````^V
MA8)^__\\00^%@`````^VA8-^__\\0W5U#[:%A'[__SQ(=6H/MH6%?O__/$5U
M7XM]\+H"````2,?&QO___^A3O___2(VU@'[__XM]\+HI````Z'^\__](BPT8
M="``2(M%T$B-E8!^__](BW7H2(M]Z$F)P4F)T$B)\KX'?$``N`````#HG;W_
M_^D@`0``2(V]@/[__^CT\___ZQ:+5?1(C;6`?O__2(V]@/[__^A6]/__2(VU
M@'[__XM]\+H`@```Z!"\__^)1?2#??0`?\V+??#HK[O__TB-M8#^__](C;U@
M?O__Z&SW___'1?@`````ZS2+1?A(F`^VA`5@?O__#[;0BT7X`<!(F$B-O0#_
M__](`<>^%GQ``+@`````Z`.]__^#1?@!@WWX$W[&QH4H____`$B+#3MS(`!(
MBT702(V5`/___TB+=>A(BWWH28G!28G02(GRO@=\0`"X`````.C`O/__ZT:^
M6'M``+_,>D``N`````#HB<'__^@5O/__B<%(BS7L<B``2(M%T$B+5>A(BWWH
M28G!08G(2(GQOAM\0`"X`````.AXO/__2(MUZ+^1>D``N`````#H1,'__TB+
M?>CHYO?__TB+1>A(B87`??__2(N%P'W__\G#54B)Y4B![-````!(B;U(____
MB;5$____2,=%\`````!(B[U(____Z-R[__](B47@2(-]X``/A&,!``#I)P$`
M`$B+?>A(@\<3OJ=Z0`#H!KW__X7`#X0-`0``2(M]Z$B#QQ.^*7Q``.CLO/__
MA<`/A/,```!(BX5(____2,?!_____TB)A3C___^X`````/Q(B[TX____\JY(
MB<A(]]!(@^@!B<)(BT7H2(/`$TC'P?____](B84P____N`````#\2(N],/__
M__*N2(G(2/?02(/H`8T$`H/``HE%_(M%_$AC^.@QNO__2(E%\$B+3>A(@\$3
M2(N52/___TB+??"^+'Q``+@`````Z#N[__](C;50____2(M]\.@;$P``@_C_
M="N+A6C___\E`/```#T`0```=1F#O43___\`=!!(BWWPO@$```#HM?[__^L)
M2(M]\.@BNO__2(M]\.B9NO__2,=%\`````!(BWW@Z-B\__](B47H2(-]Z``/
MA<'^__](BWW@Z&"\__](@[U(____`'0,2(N]2/___^CJN?__R<-52(GE2(/L
M($B)?>A(BWWHZ$S&__](B47P2(M]\.CNQ?__2(E%^+@`````Z'#)__^%P'1"
M2(-]Z`!T.TB+1>@/M@"$P'0P2(M]^+[R>T``Z*2Z__](.T7X=1Q(BWWHO@$`
M``#H^/W__TB+??"^`````.CJ_?__R<-52(GE4TB#[`A(B7WP2(L%['`@`$B+
M4`B+!;9P(`")0CA(BP78<"``2(M0"$B+!;5P(``/MT`@#[?`B4(\2(L%O'`@
M`$B+6`B^`````+^^>T``Z&F[__](B4-`2(L%GG`@`$B+4`A(BP6#<"``2(E"
M2$B+!8AP(`!(BU`(2(L%/7`@`$B)0E!(BP5R<"``2(M`"$C'0%@`````2(/$
M"%O)PU5(B>5(@^P02(E]^+______Z!FY__^^`````+^@9T``Z)J[___)PU5(
MB>5(@^Q@2(E]R,=%[`````#&!19P(``!O[!Z0`"X`````.C^O?__2(E%\$B#
M??``=!I(BT7P#[8`/#%U#TB+1?!(@\`!#[8`A,!T"K@`````Z#K&__^Z"@``
M`+X!````OS)\0`#H#+C__TB)1=!(@WW0``^$ZP```$B+1=!(BP!(BT`X2(M`
M($B)1=C'1>@!````Z8X```"+=>B#[@%(BWW8N@````#H2KG__TB)1>!(@WW@
M`'1^2(M%X$B+`(M`#"4```0`A<!T$TB+1>!(BP!(BP!(BP!(B46HZQI(BT7@
M2(LXN@(```"^`````.BSNO__2(E%J(M%Z$B82,'@`TB)PDB+!:1_(`!(C00"
M2(LX2(MUJ.A<N?__A<!U%X-%[`&#1>@!BP5Z?R``.47H#XQC____BP5K?R``
M@^@!.T7L=2''1>@!````ZPU(BWW8Z!&W__^#1>@!BP5'?R``.47H?.BZ!```
M`+X!````OS=\0`#H_K;__TB)1=!(@WW0`'1%2(M%T$B+`$B+0#A(BSB^.7Q`
M`.@;M___2(M%T$B+`$B+0#A(BP"+0`PE`$```(7`=!-(BT702(L`2(M`.$B+
M..B>N/__N@0```"^`0```+\^?$``Z)JV__](B4702(-]T`!T6$C'1?@`````
MOYIZ0`"X`````.@GO/__2(E%^$B#??@`=!E(BT702(L`2(M`.$B+.$B+=?CH
MEK;__^L=2(L%A7X@`$B+,$B+1=!(BP!(BT`X2(LXZ%2Z___&!>AM(```2,<%
MQ6T@``````"_D7I``+@`````Z,6[__](B04W?B``2(L%,'X@`$B%P`^%^```
M`$B+/3!^(`#H_O/__TB)!11^(`!(BP4=?B``2(E%L$B+1=!(BP!(BT`X2(L`
MBT`,)0``!`"%P'0:2(M%T$B+`$B+0#A(BP!(BP!(BP!(B46XZR%(BT702(L`
M2(M`.$B+.+H"````O@````#HP+C__TB)1;A(BW6P2(M]N.C_M/__B47H2(M%
MT$B+`$B+0#A(BP"+0`PE```$`(7`=!I(BT702(L`2(M`.$B+`$B+`$B+`$B)
M1<#K(4B+1=!(BP!(BT`X2(LXN@(```"^`````.A;N/__2(E%P$B+!5A](`!(
MBS"+3>A(BU7`OT!\0`"X`````.BWM___2(L]*'T@`+[M`0``Z`:X__^)1>B#
M?>@`="^#?>@1="F#?>C_="-(BQ4"?2``2(L%"WT@`$B+,(M-Z+]P?$``N```
M``#H;K?__\G#54B)Y>BKN/__NKY[0`"^:&A``+^^?$``Z&^W__](B<>^OGM`
M`.C2M/__R<-52(GE2(/L,(E][$B)=>!(B578O@$```"_"````.C^M?__2(D%
M+VP@``^V!3!L(`"$P'4XZ,>T__](B05P?"``2(L%:7P@`$B%P'4*OP$```#H
MRK/__TB+/5-\(`#H/K7__\<%M&L@```````/M@6U:R``@\@"B`6L:R``#[8%
MI6L@`(/(`8@%G&L@`(-][/M]#[_`V&``N`````#HG[;__XM%[(/`!4B82(T\
MQ0````#H*K;__TB)!0M\(`!(BQ4$?"``2(M%X$B+`$B)`DB+!?-[(`!(@\`(
M2,<`TWQ``$B+!>%[(`!(@\`02,<``'U``,<%Q'L@``,```"+!;Y[(`!(F$C!
MX`-(B<)(BP6V>R``2(T$`DC'`-9\0`"+!9U[(`"#P`&)!91[(`#'1?P!````
MZSB+!85[(``#1?Q(F$C!X`-(B<)(BP5Z>R``2(T$`DB-4/B+1?Q(F$C!X`-(
M`T7@2(L`2(D"@T7\`8M%_#M%['S`BP5%>R```T7L2)A(P>`#2(G"2(L%.GL@
M`$B-!`)(@^@(2,<``````$B+#21[(`"+!19[(``#1>R-4/](BSWY>B``0;@`
M````OB1L0`#H*;+__XE%^(-]^`!U#TB+/=EZ(`#HE++__XE%^$B+/<IZ(`#H
M9;3__[_`>D``N`````#H1;C__TB%P'4Z2(L%LGH@`$B%P'46OY%Z0`"X````
M`.@EN/__2(D%EWH@`$B+!9!Z(`!(A<!T#$B+/81Z(`#HG_C__TB+/7!Z(`#H
M>['__XM%^,G#D)"0D)"02(/L"$B+#?UF(`!(BSW>9B``2(L!2(L7BS!(@^@$
M2(D!2(L%$&<@`$B+"$ACQDB-!,%(*<)(P>H#A=)U$HU&`4B82(U$P?A(B0=(
M@\0(PTB-/;I;```QP.B3M/__#Q\`3(EL).A,B7PD^$B)7"302(EL)-A,B60D
MX$R)="3P2(/L2$B+!6=F(`!(BQ5X9B``3(L]H68@`$B+&$B+`DF++T2+($B#
MZ`1(B0)!C40D`4B83(TLQ0````!*BWPM`/9'#@0/A,@!``!(BP=,BS!)8\1(
MC43%`$@IPTC!^P.#ZP$/CNX!``!)BP<Q[4F+7`4(2(7;=#>+0PRI```/!P^$
M30$``*D```0`#X2R`0``2(L#2(L`_$B--59<``"Y!0```$B)Q_.F#X4D`0``
M2(LUM64@`$B-%59<``!(C3U<7```Z,JS__](BS6K92``2(T5/%P``$B-/5M<
M``#HL+/__TB+-;%E(`!(C14B7```2(T]7%P``.B6L___2(LUKV4@`$B-%0A<
M``!(C3U=7```Z'RS__](BS6-92``2(T5[EL``$B-/6!<``#H8K/__TB+-6ME
M(`!(C1746P``2(T]8EP``.A(L___2(T]J5L``#'VZ$JS__](C3U=7```2(D%
MG'@@`,<%FG@@``````#H';+__TB%P'07,<FZ"@```#'V2(G'Z#>Q__^)!7EX
M(`!)BQ=(BP7W9"``28E$%0!-`R](BP7(9"``3(DH2(M<)!A(BVPD($R+9"0H
M3(ML)#!,BW0D.$R+?"1`2(/$2,-FD$B%[4R)\$B-#1I;``!(C1456P``=#Y)
MB=%(C3W(60``2(T5^UH``$F)P$R)]C'`2(E<)`A(B2PDZ&.R__\/'P"Z(@``
M`#'VZ-2R__])B<;I*O[__TB-#<U:``!(C2W*6@``2(G*2(G(ZZQF#Q]$``"Z
M(@```#'V2(G?Z*&R___I0/[__TB-%85:``!(C3V)6@``3(GV,<#HI*___S'V
M2(G'Z(JN__](A<!(B<-T%8M`#$B-+5A:``"I```/!P^%\/W__TB-%4E:``!(
MC3U*6@``3(GV,<!(C2TV6@``Z%ZO__\Q]DB)Q^A$KO__2(G#Z:S]__]F#Q]$
M``!F#Q]$``!,B70D\$R)?"3X2(E<)-!(B6PDV$R)9"3@3(EL).A(@^PX2(L-
MCV,@`$R+-;AC(`!,BSUI8R``2(L!28L7BQA(@^@$2(D!2&/#2,'@`TD#!D@I
MPDC!Z@.%T@^%C@```$B+!4IC(`!(BP#V0"4@='1(BQ4:8R``2(M`&$B+$DB+
M+,)(BP6H=B``2(GO2(L`2(LPZ)JN___V10U`C4,!38LN3&/@2HT<Y0````!T
M"$B)[^@KL/__2XELY0!)`QY)B1](BUPD"$B+;"003(MD)!A,BVPD($R+="0H
M3(M\)#!(@\0XP^AXK___2(G%ZY1(C3T&6@``,<#HI;#__P\?1```2(E<)-!,
MB6PDZ$R)?"3X2(EL)-A,B60DX$R)="3P2(/L.$B+%8]B(`!,BRVX8B``3(L]
M:6(@`$B+`DF+#XLP2(/H!$B)`DF+50!(8\9(C03"2"G!2(G+2,'K`XU#_H/X
M`0^'X0```(U&`4B82(TLQ0````!(BSPJ]D<.!`^$G@```$B+!TR+,$F+10!(
MBWP%"/9'#@%T>4B+!TR+8!B#^P)(C15P60``?A5)BT4`2(M\!1#V1PX$='M(
MBP=(BQ!(B>M)`UT`3(GF3(GWZ.^O__](B<?H%[#__TB)Q^@?K?__2(D#20-M
M`$F)+TB+7"0(2(ML)!!,BV0D&$R+;"0@3(MT)"A,BWPD,$B#Q#C#9I#HJZW_
M_TF)Q.N$9@\?1```N@(````Q]NCTK___28G&Z53___^Z`@```#'VZ."O__](
MB<+I=____TB-/<E6```QP.A*K___9BX/'X0``````$B![-@```!(B50D,`^V
MT$B)="0H2(T$E0````!(C14_````2(E,)#A,B40D0$R)3"1(2(GF2"G"2(V$
M),\```#_X@\I>/$/*7#A#REHT0\I8,$/*5BQ#RE0H0\I2)$/*4"!2(V$).``
M``#'!"0(````QT0D!#````!(B40D"$B-1"0@2(E$)!#H@ZS___9`#@1(B<%T
M.DB+`$B+0`A(B40D&$B+`4B+,$B+5"082(L]''0@`$B#P@%(B50D&.@>K?__
M2('$V````,-F#Q]$``!(C70D&+H"````2(G'Z-ZN__](B<;KP68/'X0`````
M`$R);"3P3(ET)/A(B5PDV$B);"3@3(ED).A(@^PH2(L-1&`@`$R++6U@(`!,
MBS4>8"``2(L!28L6BS!(@^@$2(D!28M-`$ACQDB-!,%(*<)(P?H#@_H"#X6]
M````C48!2)A(C2S%`````$B+/"GV1PX!='!(BP=(BU@828M%`$B+?`4(]D<.
M!'1G2(L'2(LP2(G?2(GKZ':M__])`UT`28G$Z&JL__]-A>1(B0-T4TF+10!,
MB>9(BWP%`.@!JO__20-M`$F)+DB+'"1(BVPD"$R+9"003(ML)!A,BW0D($B#
MQ"C#Z(BK__](B</KC0\?`#'VN@(```#HU*W__TB)QNN.Z'JK__](C3W"50``
M2(G&,<#H^?W__^NF2(T]^%0``#'`Z"FM__]F#Q^$``````!,B70D\$R)?"3X
M2(E<)-!(B6PDV$R)9"3@3(EL).A(@^PX2(L-#U\@`$R+-3A?(`!,BSWI7B``
M2(L!28L7BS!(@^@$2(D!28L.2&/&2(T$P4@IPDC!^@.#Z@$/A=T```"-1@%(
MF$R-),4`````2HL\(?9'#@$/A+4```!(BP=(BV@82(L%IUX@`$B+`/9`)2`/
MA(H```!(BQ5S7B``2(M`&$B+$DB+',)(B>\Q[>C>JO__A<!`#Y3%A>UT24AC
M]4B)WTV++NC&J/__]D,-0'0(2(G?Z(BK__]+B1PL30,F38DG2(M<)`A(BVPD
M$$R+9"083(ML)"!,BW0D*$R+?"0P2(/$.,/H1JK__TB-/8Y4``!(B<8QP.C%
M_/__ZY\/'P#HNZK__TB)P^E[____#Q\`Z`NJ__](B<7I1?___TB-/>13```Q
MP.C5J___#Q]$``!(B5PDV$R);"3P3(ET)/A(B6PDX$R)9"3H2(/L*$B+%<1=
M(`!,BRWM72``3(LUGET@`$B+`DF+#HLP2(/H!$B)`DF+50!(8\9(C03"2"G!
M2(G+2,'K`XU#_X/X`0^'ZP```(U&`4B82(TLQ0````!(BSPJ]D<.!`^$DP``
M`$B+!TR+(#'2@^L!?AQ)BT4`2(M\!0CV1PX!#X2'````2(L'BU`8@^(!@SV[
M<"```4R)YTB)ZQGV@\8"B?"`S`&%T@]%\.AYJO__20-=`$F)Q.B]J?__387D
M2(D#=%I)BT4`3(GF2(M\!0#H5*?__TD#;0!)B2Y(BQPD2(ML)`A,BV0D$$R+
M;"083(MT)"!(@\0HP[H"````,?;H-*O__TF)Q.E?____Z,>H__^)PH/B`6:0
MZ7'____HQJC__TB-/0Y3``!(B<8QP.A%^___ZY](C3VT4@``,<#H=:K__Y"0
MD)"0\\,/'X``````#Q^``````$R)9"3@3(EL).A)B=5,B70D\$R)?"3X28GV
M2(E<)-!(B6PDV$B#[#A!B?_H>*;__TB-!>59(`!(C17>62``2"G028G$2<'\
M`W0>,>U(B=.02(/%`4R)ZDR)]D2)__\32(/#"$DY['7H2(M<)`A(BVPD$$R+
M9"083(ML)"!,BW0D*$R+?"0P2(/$.,.0D)"0D$B)\DB)_K\!````Z5"I__](
MB?)(B?Z_`0```.FPJ/__54B)Y5.[4--@`$B#[`A(BP5;62``2(/X_W04#Q]$
M``!(@^L(_]!(BP-(@_C_=?%(@\0(6\G#D)!(@^P(Z$^J__](@\0(PP``````
M`````````````````````````````0`"``````!P97)L>'-I+F,`1'EN84QO
M861E<CHZ8F]O=%]$>6YA3&]A9&5R`"]P<F]C+W-E;&8O97AE`"\`.@!E>&4`
M+W!R;V,O)6DO)7,`4$%27U1%35``4$%27U!23T=.04U%`"X`)7,E<R5S`%!!
M4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%27T1%0E5'
M`%!!4E]#04-(10!005)?05)'0P!005)?05)'5E\P`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`````````7U]%3E9?
M4$%27T-,14%.7U\@("`@("`@("`@("`@("```$Q$7TQ)0E)!4EE?4$%42`!,
M24)0051(`$Q)0E)!4EE?4$%42`!0051(`$193$1?3$E"4D%265]0051(``!#
M.EQ414U0`"]T;7``5$U01$E2`%1%35!$25(`5$5-4`!435``55-%4@!54T52
M3D%-10!P87(M`%-94U1%30`E<R5S)7,E<P`E<R5S8V%C:&4M)7,E<P`E,#)X
M`"5S)7-T96UP+25U)7,`+BX`)7,O)7,`05)'5@`8`'!E<FP`,``E<SH@97AE
M8W5T:6]N(&]F("5S(&9A:6QE9"`M(&%B;W)T:6YG('=I=&@@)6DN"@`E<SH@
M8W)E871I;VX@;V8@<')I=F%T92!T96UP;W)A<GD@<W5B9&ER96-T;W)Y("5S
M(&9A:6QE9"`M(&%B;W)T:6YG('=I=&@@)6DN"@!);G1E<FYA;',Z.E!!4CHZ
M0D]/5``M90`M+0``````````<&%R+G!L````````````````````````````
M```````C(2]U<W(O8FEN+W!E<FP*"F5V86P@)V5X96,@+W5S<B]B:6XO<&5R
M;"`@+5,@)#`@)'LQ*R(D0")])PH@("`@:68@,#L@(R!N;W0@<G5N;FEN9R!U
M;F1E<B!S;VUE('-H96QL"@IP86-K86=E(%]?<&%R7W!L.PH*(R`M+2T@5&AI
M<R!S8W)I<'0@;75S="!N;W0@=7-E(&%N>2!M;V1U;&5S(&%T(&-O;7!I;&4@
M=&EM92`M+2T*(R!U<V4@<W1R:6-T.PH*(VQI;F4@,34Y"@IM>2`H)'!A<E]T
M96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%2
M7T-,14%.?2D@>PH@("`@=6YL:6YK($!T;7!F:6QE.PH@("`@<FUD:7(@)'!A
M<E]T96UP.PH@("`@)'!A<E]T96UP(#U^('-[6UY<7"]=*EM<7"]=/R1]>WT[
M"B`@("!R;61I<B`D<&%R7W1E;7`["GT@?0H*0D5'24X@>PH@("`@26YT97)N
M86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ
M0D]/5#L*"B`@("!E=F%L('L*"E]P87)?:6YI=%]E;G8H*3L*"FEF("AE>&ES
M=',@)$5.5GM005)?05)'5E\P?2!A;F0@)$5.5GM005)?05)'5E\P?2`I('L*
M("`@($!!4D=6(#T@;6%P("1%3E9[(E!!4E]!4D=67R1?(GTL("@Q("XN("1%
M3E9[4$%27T%21T-]("T@,2D["B`@("`D,"`]("1%3E9[4$%27T%21U9?,'T[
M"GT*96QS92!["B`@("!F;W(@*&ME>7,@)45.5BD@>PH@("`@("`@(&1E;&5T
M92`D14Y6>R1??2!I9B`O7E!!4E]!4D=67R\["B`@("!]"GT*"FUY("1Q=6EE
M="`]("$D14Y6>U!!4E]$14)51WT["@HC(&9I>"`D<')O9VYA;64@:68@:6YV
M;VME9"!F<F]M(%!!5$@*;7D@)4-O;F9I9R`]("@*("`@('!A=&A?<V5P("`@
M(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`H@("`@7V5X92`@
M("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N
M97AE)R`Z("<G*2P*("`@(%]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I
M;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["@I?<V5T7W!R;V=N86UE*"D["E]S
M971?<&%R7W1E;7`H*3L*"B,@36%G:6,@<W1R:6YG(&-H96-K:6YG(&%N9"!E
M>'1R86-T:6YG(&)U;F1L960@;6]D=6QE<R![>WL*;7D@*"1S=&%R=%]P;W,L
M("1D871A7W!O<RD["GL*("`@(&QO8V%L("1324=[7U]705).7U]](#T@<W5B
M('M].PH*("`@(",@0VAE8VL@9FEL92!T>7!E+"!G970@<W1A<G0@;V8@9&%T
M82!S96-T:6]N('M[>PH@("`@;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R
M(&QA<W0["B`@("!B:6YM;V1E*%]&2"D["@H@("`@;7D@)&)U9CL*("`@('-E
M96L@7T9(+"`M."P@,CL*("`@(')E860@7T9(+"`D8G5F+"`X.PH@("`@;&%S
M="!U;FQE<W,@)&)U9B!E<2`B7&Y005(N<&U<;B(["@H@("`@<V5E:R!?1D@L
M("TQ,BP@,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@<V5E:R!?1D@L
M("TQ,B`M('5N<&%C:R@B3B(L("1B=68I+"`R.PH@("`@<F5A9"!?1D@L("1B
M=68L(#0["@H@("`@)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["B`@("`C
M('U]?0H*("`@(",@17AT<F%C=&EN9R!E86-H(&9I;&4@:6YT;R!M96UO<GD@
M>WM["B`@("!M>2`E<F5Q=6ER95]L:7-T.PH@("`@=VAI;&4@*"1B=68@97$@
M(D9)3$4B*2!["B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("`@("`@
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PH*("`@("`@("!M
M>2`D9G5L;&YA;64@/2`D8G5F.PH@("`@("`@(&]U=',H<7$H56YP86-K:6YG
M(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*("`@("`@("!M>2`D8W)C(#T@*"`D
M9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F
M.PH@("`@("`@(&UY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH
M/SHN*B\I/R@N*BDH7"XN*BE\*3L*"B`@("`@("`@<F5A9"!?1D@L("1B=68L
M(#0["B`@("`@("`@<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I
M.PH*("`@("`@("!I9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH
M/SIP;7QP;'QI>'QA;"DD+VDI('L*("`@("`@("`@("`@;7D@*"1O=70L("1F
M:6QE;F%M92D@/2!?=&5M<&9I;&4H)&5X="P@)&-R8RD["B`@("`@("`@("`@
M(&EF("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@
M("`@("`@("`@("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@("`@("`@
M("`@8VQO<V4@)&]U=#L*("`@("`@("`@("`@("`@(&-H;6]D(#`W-34L("1F
M:6QE;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B`@("`@("`@
M("`@("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL
M;F%M93L*("`@("`@("!]"B`@("`@("`@96QS:68@*"`D9G5L;&YA;64@/7X@
M;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PH@
M("`@("`@("`@("`C('-H;W5L9"!B92!M;W9E9"!T;R!?=&5M<&9I;&4H*0H@
M("`@("`@("`@("!M>2`D9FEL96YA;64@/2`B)$5.5GM005)?5$5-4'TO)&)A
M<V5N86UE)&5X="(["B`@("`@("`@("`@(&]U=',H(E-(3$E".B`D9FEL96YA
M;65<;B(I.PH@("`@("`@("`@("!O<&5N(&UY("1O=70L("<^)RP@)&9I;&5N
M86UE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@
M("`@("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@("`@("!C;&]S92`D
M;W5T.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)')E
M<75I<F5?;&ES='LD9G5L;&YA;65](#T*("`@("`@("`@("`@)%!!4CHZ2&5A
M=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["B`@("`@("`@("`@("`@
M("!B=68@/3X@)&)U9BP*("`@("`@("`@("`@("`@(&-R8R`]/B`D8W)C+`H@
M("`@("`@("`@("`@("`@;F%M92`]/B`D9G5L;&YA;64L"B`@("`@("`@("`@
M('T["B`@("`@("`@?0H@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@
M?0H@("`@(R!]?7T*"B`@("!L;V-A;"!`24Y#(#T@*'-U8B!["B`@("`@("`@
M;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PH*("`@("`@("!R971U<FX@:68@
M<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["@H@("`@("`@(&UY("1F:6QE;F%M
M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*("`@
M("`@("`@("`@;7D@)&ME>3L*("`@("`@("`@("`@9F]R96%C:"`H:V5Y<R`E
M<F5Q=6ER95]L:7-T*2!["B`@("`@("`@("`@("`@("!N97AT('5N;&5S<R`O
M7%$D;6]D=6QE7$4D+SL*("`@("`@("`@("`@("`@("1K97D@/2`D7SL@;&%S
M=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!D96QE=&4@)')E<75I<F5?
M;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PH@("`@("`@('T@;W(@<F5T
M=7)N.PH*("`@("`@("`D24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N
M86UE+R1M;V1U;&4B.PH*("`@("`@("!I9B`H)$5.5GM005)?0TQ%04Y](&%N
M9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PH@("`@("`@("`@("!M>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PH@("`@("`@
M("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@('!R:6YT("1F:"`D9FEL
M96YA;64M/GMB=69].PH@("`@("`@("`@("!S965K*"1F:"P@,"P@,"D["B`@
M("`@("`@("`@(')E='5R;B`D9F@["B`@("`@("`@?0H@("`@("`@(&5L<V4@
M>PH@("`@("`@("`@("!M>2`H)&]U="P@)&YA;64I(#T@7W1E;7!F:6QE*"<N
M<&TG+"`D9FEL96YA;64M/GMC<F-]*3L*("`@("`@("`@("`@:68@*"1O=70I
M('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@
M("`@("!P<FEN="`D;W5T("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@
M("`@("!C;&]S92`D;W5T.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&]P
M96X@;7D@)&9H+"`G/"<L("1N86UE(&]R(&1I92`D(3L*("`@("`@("`@("`@
M8FEN;6]D92@D9F@I.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@
M('T*"B`@("`@("`@9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T
M(&9I;F0@)&UO9'5L92%<;B(["B`@("!]+"!`24Y#*3L*"B`@("`C($YO=R!L
M;V%D(&%L;"!B=6YD;&5D(&9I;&5S('M[>PH*("`@(",@:6YI=&EA;&EZ92!S
M:&%R960@;V)J96-T('!R;V-E<W-I;F<*("`@(')E<75I<F4@6%-,;V%D97([
M"B`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E($-A<G`Z.DAE
M879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@("!005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H@("`@(R!N;W<@;&5T)W,@=')Y
M(&=E='1I;F<@:&5L<&5R(&UO9'5L97,@9G)O;2!W:71H:6X*("`@(')E<75I
M<F4@24\Z.D9I;&4["@H@("`@(R!L;V%D(')E<W0@;V8@=&AE(&=R;W5P(&EN
M"B`@("!W:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER
M95]L:7-T*5LP72D@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`]
M(%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@<F5Q=6ER
M92`D9FEL96YA;64@=6YL97-S("1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA
M;64@/7X@+T)31%!!3B\["B`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[
M)&9I;&5N86UE?3L*("`@('T*"B`@("`C('U]?0H*("`@(&QA<W0@=6YL97-S
M("1B=68@97$@(E!+7#`P,UPP,#0B.PH@("`@)'-T87)T7W!O<R`]("AT96QL
M(%]&2"D@+2`T.PI]"B,@?7U]"@HC($%R9W5M96YT('!R;V-E<W-I;F<@>WM[
M"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A
M8VAE7VYA;64I.PH*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=]
M.PH*(R!$;VXG="!S=V%L;&]W(&%R9W5M96YT<R!F;W(@8V]M<&EL960@97AE
M8W5T86)L97,@=VET:&]U="`M+7!A<BUO<'1I;VYS"FEF("@A)'-T87)T7W!O
M<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@
M>PH@("`@;7D@)61I<W1?8VUD(#T@<7<H"B`@("`@("`@<"`@(&)L:6)?=&]?
M<&%R"B`@("`@("`@:2`@(&EN<W1A;&Q?<&%R"B`@("`@("`@=2`@('5N:6YS
M=&%L;%]P87(*("`@("`@("!S("`@<VEG;E]P87(*("`@("`@("!V("`@=F5R
M:69Y7W!A<@H@("`@*3L*("`@('=H:6QE("A`05)'5BD@>PH@("`@("`@("1!
M4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0[
M"@H@("`@("`@(&EF("@D,2!E<2`G22<I('L*("`@("`@("`@("`@=6YS:&EF
M="!`24Y#+"`D,CL*("`@("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q("=-
M)RD@>PH@("`@("`@("`@("!E=F%L(")U<V4@)#(B.PH@("`@("`@('T*("`@
M("`@("!E;'-I9B`H)#$@97$@)T$G*2!["B`@("`@("`@("`@('5N<VAI9G0@
M0'!A<E]A<F=S+"`D,CL*("`@("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q
M("=/)RD@>PH@("`@("`@("`@("`D;W5T(#T@)#(["B`@("`@("`@?0H@("`@
M("`@(&5L<VEF("@D,2!E<2`G8B<I('L*("`@("`@("`@("`@)&)U;F1L92`]
M("=S:71E)SL*("`@("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q("=")RD@
M>PH@("`@("`@("`@("`D8G5N9&QE(#T@)V%L;"<["B`@("`@("`@?0H@("`@
M("`@(&5L<VEF("@D,2!E<2`G<2<I('L*("`@("`@("`@("`@)'%U:65T(#T@
M,3L*("`@("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q("=,)RD@>PH@("`@
M("`@("`@("!O<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A
M;FYO="!O<&5N(&QO9SH@)"$B.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H
M)#$@97$@)U0G*2!["B`@("`@("`@("`@("1C86-H95]N86UE(#T@)#(["B`@
M("`@("`@?0H*("`@("`@("!S:&EF="A`05)'5BD["@H@("`@("`@(&EF("AM
M>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PH@("`@("`@("`@("!D96QE=&4@
M)$5.5GLG4$%27U1%35`G?3L*("`@("`@("`@("`@:6YI=%]I;F,H*3L*("`@
M("`@("`@("`@<F5Q=6ER92!005(Z.D1I<W0["B`@("`@("`@("`@("9[(E!!
M4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PH@("`@("`@("`@("`F
M>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PH@("`@("`@("`@
M("!E>&ET.PH@("`@("`@('T*("`@('T*?0H*(R!86%@@+2T@861D("TM<&%R
M+61E8G5G('-U<'!O<G0A"@HC('U]?0H*(R!/=71P=70@;6]D92`H+4\I(&AA
M;F1L:6YG('M[>PII9B`H)&]U="D@>PH@("`@>PH@("`@("`@("-L;V-A;"`D
M24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<[
M"B`@("`@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@("`@("!R97%U:7)E($%R
M8VAI=F4Z.EII<#L*("`@('T*"@H@("`@;7D@)'!A<B`]('-H:69T*$!!4D=6
M*3L*("`@(&UY("1Z:7`["@H*("`@(&EF("AD969I;F5D("1P87(I('L*("`@
M("`@("!O<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I
M;F0@)R1P87(G.B`D(2(["B`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@
M(&)L97-S*"1F:"P@)TE/.CI&:6QE)RD["@H@("`@("`@("1Z:7`@/2!!<F-H
M:79E.CI::7`M/FYE=SL*("`@("`@("`H("1Z:7`M/G)E861&<F]M1FEL94AA
M;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"B`@
M("`@("`@("`@(&]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*("`@
M('T*"@H@("`@;7D@)65N=B`](&1O('L*("`@("`@("!I9B`H)'II<"!A;F0@
M;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PH@("`@
M("`@("`@("`D;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*("`@("`@("`@("`@
M)&UE=&$@/7X@<R]>7%,N*B\O;7,["B`@("`@("`@("`@("1M971A(#U^("]>
M("`H6UXZ72LI.B`H+BLI)"]M9SL*("`@("`@("!]"B`@("!].PH*("`@(",@
M3W!E;B!I;G!U="!A;F0@;W5T<'5T(&9I;&5S('M[>PH@("`@;&]C86P@)"\@
M/2!<-#L*"B`@("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@("`@;W!E;B!0
M05(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*("`@("`@("!B:6YM
M;V1E*%!!4BD["B`@("`@("`@9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE
M(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PH@("`@?0H*("`@($-R
M96%T95!A=&@H)&]U="D@.PH@("`@"B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W*`H@("`@("`@("1O=70L"B`@("`@("`@24\Z.D9I;&4Z.D]?0U)%050H
M*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H
M*2P*("`@("`@("`P-S<W+`H@("`@*2!O<B!D:64@)"$["B`@("!B:6YM;V1E
M*"1F:"D["@H@("`@)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A
M7W!O<R`Z('5N9&5F.PH@("`@<V5E:R!?1D@L(#`L(#`["B`@("!M>2`D;&]A
M9&5R(#T@<V-A;&%R(#Q?1D@^.PH@("`@:68@*"$D14Y6>U!!4E]615)"051)
M37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["B`@("`@("`@
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@("`@("`@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*("`@
M('T*("`@(&9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*("`@
M("`@("!M>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PH@("`@("`@("1V
M86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PH@("`@("`@(&UY
M("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*("`@
M("`@("!M>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PH@
M("`@("`@("1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*("`@("`@("`@("`@
M)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D
M<V5T*2DI"B`@("`@("`@?65G.PH@("`@?0H@("`@)&9H+3YP<FEN="@D;&]A
M9&5R*3L*("`@("0O(#T@=6YD968["B`@("`C('U]?0H*("`@(",@5W)I=&4@
M8G5N9&QE9"!M;V1U;&5S('M[>PH@("`@:68@*"1B=6YD;&4I('L*("`@("`@
M("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("`@("`@4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PH@("`@("`@(&EN:71?:6YC*"D["B`@("`@("`@
M<F5Q=6ER95]M;V1U;&5S*"D["@H@("`@("`@(&UY($!I;F,@/2!S;W)T('L*
M("`@("`@("`@("`@;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0H@("`@("`@
M('T@9W)E<"!["B`@("`@("`@("`@("$O0E-$4$%.+PH@("`@("`@('T@9W)E
M<"!["B`@("`@("`@("`@("@D8G5N9&QE(&YE("=S:71E)RD@;W(*("`@("`@
M("`@("`@*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*
M("`@("`@("`@("`@("1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP
M?2D["B`@("`@("`@?2!`24Y#.PH*("`@("`@("!I9B`H)$-O;F9I9WM?9&5L
M:6U](&5Q("=<7"<I('L@<WM<7'U[+WUG(&9O<B!`:6YC('T*"B`@("`@("`@
M;7D@)69I;&5S.PH@("`@("`@("]>7SPH+BLI)"\@86YD("1F:6QE<WLD,7TK
M*R!F;W(@:V5Y<R`E.CH["B`@("`@("`@)&9I;&5S>R1??2LK(&9O<B!V86QU
M97,@)4E.0SL*"B`@("`@("`@;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF
M:6=[;&EB7V5X='T["B`@("`@("`@;7D@)7=R:71T96X["@H@("`@("`@(&9O
M<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*("`@("`@("`@("`@;7D@*"1N
M86UE+"`D9FEL92D["@H@("`@("`@("`@("!F;W)E86-H(&UY("1D:7(@*$!I
M;F,I('L*("`@("`@("`@("`@("`@(&EF("@D;F%M92`]("1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)%]]*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&4@
M/2`D7SL*("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;
M7D-C72DI7%HO:2D@>PH@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA
M;64I(#T@*"0Q+"`D,BD["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("AM(5XO;&]A
M9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PH@("`@("`@("`@("`@("`@("`@
M(&EF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D
M<F5F+"`D,2D["B`@("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&5L<VEF("@M
M9B`B)&1I<B\D,2(I('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE
M+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["B`@("`@("`@("`@("`@("`@
M("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!N97AT('5N;&5S
M<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["B`@
M("`@("`@("`@(&YE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<
M+EQ1)&QI8E]E>'1<120O.PH@("`@("`@("`@("!O=71S*"!J;VEN("(B+`H@
M("`@("`@("`@("`@("`@<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I
M;&4M/GMN86UE?2`Z("1F:6QE+`H@("`@("`@("`@("`@("`@<7$H(BXN+BD*
M("`@("`@("`@("`@*3L*"B`@("`@("`@("`@(&UY("1C;VYT96YT.PH@("`@
M("`@("`@("!I9B`H<F5F*"1F:6QE*2D@>PH@("`@("`@("`@("`@("`@)&-O
M;G1E;G0@/2`D9FEL92T^>V)U9GT["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@96QS92!["B`@("`@("`@("`@("`@("!O<&5N($9)3$4L("<\)RP@)&9I
M;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["B`@("`@("`@("`@
M("`@("!B:6YM;V1E*$9)3$4I.PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@
M/2`\1DE,13X["B`@("`@("`@("`@("`@("!C;&]S92!&24Q%.PH*("`@("`@
M("`@("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<
M)&-O;G1E;G0L("1F:6QE*0H@("`@("`@("`@("`@("`@("`@(&EF("$D14Y6
M>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O
M:3L*"B`@("`@("`@("`@("`@("`C($1O(&YO="!L970@6%-,;V%D97(@<&EC
M:R!U<"!A=71O+RH@9G)O;2!E;G9I<F]N;65N=`H@("`@("`@("`@("`@("`@
M)&-O;G1E;G0@/7X@<R]G;W1O("MR971R>2`K=6YL97-S("LN*B]G;W1O(')E
M=')Y.R\*("`@("`@("`@("`@("`@("`@("!I9B!L8R@D;F%M92D@97$@;&,H
M(EA33&]A9&5R+G!M(BD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&]U
M=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B`@("`@("`@("`@("1F:"T^
M<')I;G0H(D9)3$4B*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.
M)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN
M="AS<')I;G1F*`H@("`@("`@("`@("`@("`@(B4P.'@O)7,B+"!!<F-H:79E
M.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"B`@("`@("`@
M("`@("DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG
M=&@H)&-O;G1E;G0I*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H)&-O;G1E
M;G0I.PH@("`@("`@('T*("`@('T*("`@(",@?7U]"@H@("`@(R!.;W<@=W)I
M=&4@;W5T('1H92!005(@86YD(&UA9VEC('-T<FEN9W,@>WM["B`@("`D>FEP
M+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["@H@("`@)&-A8VAE
M7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PH@("`@:68@*"$D
M8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2![
M"B`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@?'P@979A;"![
M(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@
M("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E
M<W0Z.DU$-2T^;F5W('T["@H@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G
M(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("!M>2`D<VAA
M7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@
M,#L*("`@("`@("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA
M7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@("`@("`@("1C='@M/F%D9&9I
M;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@?0H@("`@("`@(&5L
M<V4@>PH@("`@("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\
M)&]U="(I*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@
M("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@
M("!C;&]S92@D9F@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("`D8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I
M;64["B`@("!]"B`@("`D8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N
M9W1H("1C86-H95]N86UE*3L*("`@("1C86-H95]N86UE("X](")#04-(12([
M"B`@("`D9F@M/G!R:6YT*"1C86-H95]N86UE*3L*("`@("1F:"T^<')I;G0H
M<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PH@("`@
M)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PH@("`@)&9H+3YC;&]S93L*("`@
M(&-H;6]D(#`W-34L("1O=70["B`@("`C('U]?0H*("`@(&5X:70["GT*(R!]
M?7T*"B,@4')E<&%R92`D<')O9VYA;64@:6YT;R!005(@9FEL92!C86-H92![
M>WL*>PH@("`@;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PH*("`@
M(%]F:7A?<')O9VYA;64H*3L*"B`@("`C($YO=R!L;V%D('1H92!005(@9FEL
M92!A;F0@<'5T(&ET(&EN=&\@4$%2.CI,:6)#86-H92![>WL*("`@(')E<75I
M<F4@4$%2.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*
M"B`@("!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%
M7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!R97%U:7)E($9I;&4Z
M.D9I;F0["B`@("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"B`@
M("!M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("!M>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W.PH@("`@)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R
M)RD@;W(@9&EE("(D(3H@)$`B.PH@("`@)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@
M;W(@9&EE("(D(3H@)$`B.PH*("`@('!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z
M:7`["B`@("`D4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*"B`@
M("`D<75I970@/2`A)$5.5GM005)?1$5"54=].PH@("`@;W5T<RAQ<2A<)$5.
M5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["@H@("`@9F]R96%C
M:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*("`@("`@("!N97AT
M(&EF("1M96UB97(M/FES1&ER96-T;W)Y(&]R("$D14Y6>U!!4E]414U0?3L*
M("`@("`@("!M>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*
M("`@("`@("!N97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*("`@("`@
M("`@("`@7@H@("`@("`@("`@("`O/W-H;&EB+PH@("`@("`@("`@("`H/SHD
M0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\*("`@("`@("`@("`@*#\Z)$-O
M;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PH@("`@("`@("`@("`H6UXO72LI
M"B`@("`@("`@("`@("0*("`@("`@("!]>#L*("`@("`@("!M>2`D97AT<F%C
M=%]N86UE(#T@)#$["B`@("`@("`@;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P
M96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PH@
M("`@("`@("1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE
M*3L*("`@("`@("!O=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@
M=&\@(B1D97-T7VYA;64B*2D["B`@("!]"B`@("`C('U]?0I]"B,@?7U]"@HC
M($EF('1H97)E)W,@;F\@;6%I;BYP;"!T;R!R=6XL('-H;W<@=7-A9V4@>WM[
M"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PH@("`@9&EE
M(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=
M(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M
M+G!L(%T*("`@("`@("0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R
M"BX*("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@
M<VAI9G0H0$%21U8I.PI]"B,@?7U]"@IS=6(@0W)E871E4&%T:"!["B`@("!M
M>2`H)&YA;64I(#T@0%\["B`@("`*("`@(')E<75I<F4@1FEL93HZ0F%S96YA
M;64["B`@("!M>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"
M87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["B`@("`*("`@
M(')E<75I<F4@1FEL93HZ4&%T:#L*("`@(`H)1FEL93HZ4&%T:#HZ;6MP871H
M*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@
M97)R;W(*?0H*<W5B(')E<75I<F5?;6]D=6QE<R!["B`@("`C;&]C86P@)$E.
M0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH*
M("`@(')E<75I<F4@;&EB.PH@("`@<F5Q=6ER92!$>6YA3&]A9&5R.PH@("`@
M<F5Q=6ER92!I;G1E9V5R.PH@("`@<F5Q=6ER92!S=')I8W0["B`@("!R97%U
M:7)E('=A<FYI;F=S.PH@("`@<F5Q=6ER92!V87)S.PH@("`@<F5Q=6ER92!#
M87)P.PH@("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@17AP
M;W)T97(Z.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E<CL*("`@(')E<75I
M<F4@1F-N=&P["B`@("!R97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E
M($9I;&4Z.E-P96,["B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER
M92!#;VYF:6<["B`@("!R97%U:7)E($E/.CI(86YD;&4["B`@("!R97%U:7)E
M($E/.CI&:6QE.PH@("`@<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*("`@(')E
M<75I<F4@07)C:&EV93HZ6FEP.PH@("`@<F5Q=6ER92!005(["B`@("!R97%U
M:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@(')E
M<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@979A;"![(')E<75I
M<F4@4V-A;&%R.CI5=&EL('T["GT*"B,@5&AE($,@=F5R<VEO;B!O9B!T:&ES
M(&-O9&4@87!P96%R<R!I;B!M>6QD<B]M:W1M<&1I<BYC"G-U8B!?<V5T7W!A
M<E]T96UP('L*("`@(&EF("@D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?
M5$5-4'T@/7X@+R@N*RDO*2!["B`@("`@("`@)'!A<E]T96UP(#T@)#$["B`@
M("`@("`@<F5T=7)N.PH@("`@?0H*("`@(&9O<F5A8V@@;7D@)'!A=&@@*`H@
M("`@("`@("AM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!4
M14U01$E2(%1%35`@5$U0("DI+`H@("`@("`@('%W*"!#.EQ<5$5-4"`O=&UP
M("X@*0H@("`@*2!["B`@("`@("`@;F5X="!U;FQE<W,@)'!A=&@@86YD("UD
M("1P871H(&%N9"`M=R`D<&%T:#L*("`@("`@("!M>2`D=7-E<FYA;64@/2!D
M969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*0H@("`@("`@("`@("`_("97:6XS
M,CHZ3&]G:6Y.86UE*"D*("`@("`@("`@("`@.B`D14Y6>U5315).04U%?2!\
M?"`D14Y6>U5315)]('Q\("=365-414TG.PH@("`@("`@("1U<V5R;F%M92`]
M?B!S+UQ7+U\O9SL*"B`@("`@("`@;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N
M9FEG>U]D96QI;7UP87(M)'5S97)N86UE(CL*("`@("`@("!M:V1I<B`D<W1M
M<&1I<BP@,#<U-3L*("`@("`@("!I9B`H(21%3E9[4$%27T-,14%.?2!A;F0@
M;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*("`@("`@("`@
M("`@;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["B`@("`@("`@("`@
M('-E96L@)&9H+"`M,3@L(#(["B`@("`@("`@("`@('-Y<W)E860@)&9H+"!M
M>2`D8G5F+"`V.PH@("`@("`@("`@("!I9B`H)&)U9B!E<2`B7#!#04-(12(I
M('L*("`@("`@("`@("`@("`@('-E96L@)&9H+"`M-3@L(#(["B`@("`@("`@
M("`@("`@("!S>7-R96%D("1F:"P@)&)U9BP@-#$["B`@("`@("`@("`@("`@
M("`D8G5F(#U^(',O7#`O+V<["B`@("`@("`@("`@("`@("`D<W1M<&1I<B`N
M/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("!M>2`D8W1X
M(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN
M97<H,2D@?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E
M($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@("`@
M("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E
M<W0Z.DU$-2T^;F5W('T["@H@("`@("`@("`@("`@("`@(R!7;W)K87)O=6YD
M(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@
M("`@("`@("`@;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(
M03HZ5D524TE/3B!]('Q\(#`["B`@("`@("`@("`@("`@("!I9B`H)'-H85]V
M97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2![
M"B`@("`@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D<')O9VYA;64L
M(")B(BD@:68@*"1C='@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@96QS92!["B`@("`@("`@("`@("`@("`@("`@:68@*"1C='@@86YD
M(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@)&-T>"T^861D9FEL92@D9F@I.PH@("`@("`@("`@("`@("`@("`@("`@
M("!C;&]S92@D9F@I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I
M9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z
M("1M=&EM92`I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&-L;W-E*"1F
M:"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D14Y6
M>U!!4E]#3$5!3GT@/2`Q.PH@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O
M;F9I9WM?9&5L:6U]=&5M<"TD)"(["B`@("`@("`@?0H*("`@("`@("`D14Y6
M>U!!4E]414U0?2`]("1S=&UP9&ER.PH@("`@("`@(&UK9&ER("1S=&UP9&ER
M+"`P-S4U.PH@("`@("`@(&QA<W0["B`@("!]"@H@("`@)'!A<E]T96UP(#T@
M)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H
M+BLI+SL*?0H*<W5B(%]T96UP9FEL92!["B`@("!M>2`H)&5X="P@)&-R8RD@
M/2!`7SL*("`@(&UY("@D9F@L("1F:6QE;F%M92D["@H@("`@)&9I;&5N86UE
M(#T@(B1P87)?=&5M<"\D8W)C)&5X="(["@H@("`@:68@*"1%3E9[4$%27T-,
M14%.?2D@>PH@("`@("`@('5N;&EN:R`D9FEL96YA;64@:68@+64@)&9I;&5N
M86UE.PH@("`@("`@('!U<V@@0'1M<&9I;&4L("1F:6QE;F%M93L*("`@('T*
M("`@(&5L<V4@>PH@("`@("`@(')E='5R;B`H=6YD968L("1F:6QE;F%M92D@
M:68@*"UR("1F:6QE;F%M92D["B`@("!]"@H@("`@;W!E;B`D9F@L("<^)RP@
M)&9I;&5N86UE(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H)&9H*3L*("`@(')E
M='5R;B@D9F@L("1F:6QE;F%M92D["GT*"G-U8B!?<V5T7W!R;V=N86UE('L*
M("`@(&EF("@D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.
M04U%?2`]?B`O*"XK*2\I('L*("`@("`@("`D<')O9VYA;64@/2`D,3L*("`@
M('T*"B`@("`D<')O9VYA;64@?'P]("0P.PH*("`@(&EF("@D14Y6>U!!4E]4
M14U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@
M,"D@>PH@("`@("`@("1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I
M;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*("`@('T*
M"B`@("!I9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA
M;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PH@("`@("`@(&EF("AO<&5N
M(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*("`@("`@("`@("`@<F5T=7)N
M(&EF("US("1F:#L*("`@("`@("!]"B`@("`@("`@:68@*"US("(D<')O9VYA
M;64D0V]N9FEG>U]E>&5](BD@>PH@("`@("`@("`@("`D<')O9VYA;64@+CT@
M)$-O;F9I9WM?97AE?3L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*
M("`@('T*"B`@("!F;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[
M<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["B`@("`@("`@;F5X="!I9B!E
M>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-
M4'T["B`@("`@("`@)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\[
M"B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P
M<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*("`@("`@("`@("`@:68@
M+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5]
M(CL*("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(BDL(&QA<W0I"B`@("`@("`@("`@(&EF("US("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*("`@('T*?0H*<W5B(%]F:7A?<')O
M9VYA;64@>PH@("`@)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.
M04U%?3L*("`@(&EF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM
M?2D@/"`P*2!["B`@("`@("`@)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64B.PH@("`@?0H*("`@(",@6%A8("T@:&%C:R!T;R!M86ME
M(%!71"!W;W)K"B`@("!M>2`D<'=D(#T@*&1E9FEN960@)E=I;C,R.CI'971#
M=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@)$5.5GM05T1].PH@("`@)'!W9"`]
M(&!P=V1@(&EF("%D969I;F5D("1P=V0["B`@("!C:&]M<"@D<'=D*3L*("`@
M("1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I
M+R1P=V0D0V]N9FEG>U]D96QI;7TO.PH*("`@("1%3E9[4$%27U!23T=.04U%
M?2`]("1P<F]G;F%M93L*?0H*<W5B(%]P87)?:6YI=%]E;G8@>PH@("`@:68@
M*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PH@("`@("`@(')E
M='5R;CL*("`@('T@96QS92!["B`@("`@("`@)$5.5GM005)?24Y)5$E!3$E:
M141](#T@,CL*("`@('T*"B`@("!F;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%
M04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*("`@
M("`@("!D96QE=&4@)$5.5GLG4$%27R<N)%]].PH@("`@?0H@("`@9F]R("AQ
M=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PH@("`@("`@("1%3E9[
M)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S
M("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["B`@("!]"@H@("`@;7D@)'!A<E]C
M;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["@H@
M("`@:68@*"1%3E9[4$%27U1%35!]*2!["B`@("`@("`@9&5L971E("1%3E9[
M4$%27T-,14%.?3L*("`@('T*("`@(&5L<VEF("@A97AI<W1S("1%3E9[4$%2
M7T=,3T)!3%]#3$5!3GTI('L*("`@("`@("!M>2`D=F%L=64@/2!S=6)S='(H
M)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PH@("`@("`@("1%
M3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH
M7%,K*2\["B`@("!]"GT*"G-U8B!O=71S('L*("`@(')E='5R;B!I9B`D<75I
M970["B`@("!I9B`H)&QO9V9H*2!["B`@("`@("`@<')I;G0@)&QO9V9H(")`
M7UQN(CL*("`@('T*("`@(&5L<V4@>PH@("`@("`@('!R:6YT(")`7UQN(CL*
M("`@('T*?0H*<W5B(&EN:71?:6YC('L*("`@(')E<75I<F4@0V]N9FEG.PH@
M("`@<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF
M:6=[)%]]+"!Q=R@*("`@("`@("!A<F-H;&EB97AP('!R:79L:6)E>'`@<VET
M96%R8VAE>'`@<VET96QI8F5X<`H@("`@("`@('9E;F1O<F%R8VAE>'`@=F5N
M9&]R;&EB97AP"B`@("`I.PI]"@HC(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,*(R!4:&4@;6%I;B!P86-K86=E(&9O<B!S8W)I<'0@97AE8W5T:6]N"@IP
M86-K86=E(&UA:6X["@IR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!
M4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["@ID:64@<7$H
M<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.
M;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"B`@("!U;FQE<W,@+64@)'!R
M;V=N86UE.PH*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@
M/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["@I].PH*
M)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"@I#3U)%.CIE>&ET*"0Q*2!I9B`H
M)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?
M7T524D]2(&EF("0Z.E]?15)23U(["@HQ.PH*(VQI;F4@.3(P"@I?7T5.1%]?
M"@``57-A9V4Z($1Y;F%,;V%D97(Z.F1L7W5N9&5F7W-Y;6)O;',H*0```"5S
M(&]B:F5C="!V97)S:6]N("5S(&1O97,@;F]T(&UA=&-H("5S)7,E<R5S("5?
M`%5S86=E.B!$>6YA3&]A9&5R.CID;%]I;G-T86QL7WAS=6(H<&5R;%]N86UE
M+"!S>6UR968L(&9I;&5N86UE/2(D4&%C:V%G92(I````````57-A9V4Z($1Y
M;F%,;V%D97(Z.F1L7V9I;F1?<WEM8F]L*&QI8FAA;F1L92P@<WEM8F]L;F%M
M92D``````````%5S86=E.B!$>6YA3&]A9&5R.CID;%]U;FQO861?9FEL92AL
M:6)R968I`````````%5S86=E.B!$>6YA3&]A9&5R.CID;%]L;V%D7V9I;&4H
M9FEL96YA;64L(&9L86=S/3`I````````6%-?5D524TE/3@`E<SHZ)7,`,2XP
M-0`D`#HZ`&)O;W1S=')A<"!P87)A;65T97(`1'EN84QO861E<BYC`$1Y;F%,
M;V%D97(Z.F1L7VQO861?9FEL90!$>6YA3&]A9&5R.CID;%]U;FQO861?9FEL
M90!$>6YA3&]A9&5R.CID;%]F:6YD7W-Y;6)O;`!$>6YA3&]A9&5R.CID;%]U
M;F1E9E]S>6UB;VQS`$1Y;F%,;V%D97(Z.F1L7VEN<W1A;&Q?>'-U8@!$>6YA
M3&]A9&5R.CID;%]E<G)O<@!015),7T1,7TY/3DQ!6ED`57-A9V4Z($1Y;F%,
M;V%D97(Z.F1L7V5R<F]R*"D`1'EN84QO861E<@```1L#.T`!```G````Q%?_
M_UP!``#I5___?`$``(M8__^<`0``>UG__[P!``";6?__W`$``&-<___\`0``
MR5S__QP"``"E7?__/`(``+!=__]<`@``)&#__WP"``!U8/__G`(``.9A__^\
M`@``M&/__]P"```89/___`(``"2+__\<`P``GHO__SP#```SC?__7`,``.R.
M__]\`P``1I#__YP#``#7D?__O`,``'28___<`P``%)K___P#``",FO__'`0`
M`"V;__\\!```5)O__UP$```0G___?`0``#R?__^<!```C*'__]0$``#LH?__
M[`0``-RD__\,!0``W*7__RP%```\I___3`4``"RH__]D!0``7*G__X0%``"L
MJO__I`4```RL___$!0``'*S__]P%``"LK/__!`8``+RL__\<!@``%```````
M```!>E(``7@0`0,,!PB0`0``'````!P```#8)$``)0````!!#A"&`D,-!@``
M```````<````/````/TD0`"B`````$$.$(8"0PT&`````````!P```!<````
MGR5``/``````00X0A@)##08`````````'````'P```"/)D``(`````!!#A"&
M`D,-!@`````````<````G````*\F0`#(`@```$$.$(8"0PT&18,#`````!P`
M``"\````=RE``&8`````00X0A@)##08`````````'````-P```#=*4``W```
M``!!#A"&`D,-!@`````````<````_````+DJ0``+`````$$.$(8"0PT&````
M`````!P````<`0``Q"I``'0"````00X0A@)##08`````````'````#P!```X
M+4``40````!!#A"&`D,-!@`````````<````7`$``(DM0`!Q`0```$$.$(8"
M0PT&`````````!P```!\`0``^BY``,X!````00X0A@)##08`````````'```
M`)P!``#(,$``9`````!!#A"&`D,-!@`````````<````O`$``"PQ0``,)P``
M`$$.$(8"0PT&`````````!P```#<`0``.%A``'H`````00X0A@)##08`````
M````'````/P!``"R6$``E0$```!!#A"&`D,-!@`````````<````'`(``$=:
M0`"Y`0```$$.$(8"0PT&`````````!P````\`@```%Q``%H!````00X0A@)#
M#08`````````'````%P"``!:74``D0$```!!#A"&`D,-!@`````````<````
M?`(``.M>0`"=!@```$$.$(8"0PT&`````````!P```"<`@``B&5``*`!````
M00X0A@)##08`````````'````+P"```H9T``>`````!!#A"&`D,-!@``````
M```<````W`(``*!G0`"A`````$$.$(8"0PT&18,#`````!P```#\`@``06A`
M`"<`````00X0A@)##08`````````'````!P#``!H:$``O`,```!!#A"&`D,-
M!@`````````<````/`,``"1L0``L`````$$.$(8"0PT&`````````!P```!<
M`P``4&Q``$H"````00X0A@)##08`````````%``````````!>E(``7@0`1L,
M!PB0`0``%````!P```"PG/__70````!$#A``````'````#0```#XG/__Y`(`
M``!B#E".`XP%A@:#!X\"C00<````5````,B?___[`````&(.0(T$C`6&!H,'
MCP*.`QP```!T````J*#__U8!````8@Y`C@.,!88&CP*-!(,'%````)0```#H
MH?__YP````!'#N`!````'````*P```#`HO__)P$```!=#C",!(8%@P:.`HT#
M```<````S````-"C__]+`0```&(.0(T$C`6&!H,'CP*.`QP```#L`````*7_
M_UL!````70XPC`2&!8X"C0.#!@``%`````P!``!`IO__`@``````````````
M)````"0!```XIO__BP````!*C02,!4V/`HX#40Y`A@:#!P```````!0```!,
M`0``H*;__Q```````````````!0```!D`0``F*;__Q``````````````````
M````````__________\``````````/__________````````````````````
M``$``````````0`````````!`````````(L"`````````0````````"7`@``
M``````$`````````OP(````````!`````````,D"`````````0````````#7
M`@````````$`````````Y`(````````/`````````!4$````````#```````
M``#8'T````````T`````````&'I```````#U_O]O`````$`"0```````!0``
M``````"H#T````````8`````````\`-````````*`````````#\&````````
M"P`````````8`````````!4````````````````````#`````````.#58```
M`````@`````````P!@```````!0`````````!P`````````7`````````*@9
M0```````!P`````````X%T````````@`````````<`(````````)````````
M`!@`````````_O__;P````#H%D```````/___V\``````@````````#P__]O
M`````.@50```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!XTV``````````````
M```````````````&($```````!8@0```````)B!````````V($```````$8@
M0```````5B!```````!F($```````'8@0```````AB!```````"6($``````
M`*8@0```````MB!```````#&($```````-8@0```````YB!```````#V($``
M``````8A0```````%B%````````F(4```````#8A0```````1B%```````!6
M(4```````&8A0```````=B%```````"&(4```````)8A0```````IB%`````
M``"V(4```````,8A0```````UB%```````#F(4```````/8A0```````!B)`
M```````6(D```````"8B0```````-B)```````!&(D```````%8B0```````
M9B)```````!V(D```````(8B0```````EB)```````"F(D```````+8B0```
M````QB)```````#6(D```````.8B0```````]B)````````&(T```````!8C
M0```````)B-````````V(T```````$8C0```````5B-```````!F(T``````
M`'8C0```````AB-```````"6(T```````*8C0```````MB-```````#&(T``
M`````-8C0```````YB-```````#V(T````````8D0```````%B1`````````
M````````````````````:--@``````!]>D```````']Z0```````_____P``
M``#@?$```````*Y-`````````$=#0SH@*$=.52D@-"XQ+C(@,C`P-S`Q,34@
M*'!R97)E;&5A<V4I("@T+C$N,BTP+C(P,#<P,3$U+C%M9'8R,#`W+C$I``!'
M0T,Z("A'3E4I(#0N,2XR(#(P,#<P,3$U("AP<F5R96QE87-E*2`H-"XQ+C(M
M,"XR,#`W,#$Q-2XQ;61V,C`P-RXQ*0``1T-#.B`H1TY5*2`T+C$N,B`R,#`W
M,#$Q-2`H<')E<F5L96%S92D@*#0N,2XR+3`N,C`P-S`Q,34N,6UD=C(P,#<N
M,2D``$=#0SH@*$=.52D@-"XQ+C(@,C`P-S`Q,34@*'!R97)E;&5A<V4I("@T
M+C$N,BTP+C(P,#<P,3$U+C%M9'8R,#`W+C$I``!'0T,Z("A'3E4I(#0N,2XR
M(#(P,#<P,3$U("AP<F5R96QE87-E*2`H-"XQ+C(M,"XR,#`W,#$Q-2XQ;61V
M,C`P-RXQ*0``1T-#.B`H1TY5*2`T+C$N,B`R,#`W,#$Q-2`H<')E<F5L96%S
M92D@*#0N,2XR+3`N,C`P-S`Q,34N,6UD=C(P,#<N,2D``$=#0SH@*$=.52D@
M-"XQ+C(@,C`P-S`Q,34@*'!R97)E;&5A<V4I("@T+C$N,BTP+C(P,#<P,3$U
M+C%M9'8R,#`W+C$I``!'0T,Z("A'3E4I(#0N,2XR(#(P,#<P,3$U("AP<F5R
M96QE87-E*2`H-"XQ+C(M,"XR,#`W,#$Q-2XQ;61V,C`P-RXQ*0``+G-H<W1R
M=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N
M9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`
M+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE
M7VAD<@`N96A?9G)A;64`+F-T;W)S`"YD=&]R<P`N:F-R`"YD>6YA;6EC`"YG
M;W0`+F=O="YP;'0`+F1A=&$`+F)S<P`N8V]M;65N=```````````````````
M````````````````````````````````````````````````````````````
M```````````````+`````0````(```````````)``````````@```````!P`
M```````````````````!````````````````````$P````<````"````````
M`!P"0```````'`(````````@````````````````````!```````````````
M`````"$```#V__]O`@````````!``D```````$`"````````L`$````````$
M``````````@````````````````````K````"P````(`````````\`-`````
M``#P`P```````+@+````````!0````$````(`````````!@`````````,P``
M``,````"`````````*@/0```````J`\````````_!@``````````````````
M`0```````````````````#L```#___]O`@````````#H%4```````.@5````
M````^@`````````$``````````(``````````@````````!(````_O__;P(`
M````````Z!9```````#H%@```````%``````````!0````(````(````````
M````````````5P````0````"`````````#@70```````.!<```````!P`@``
M``````0`````````"``````````8`````````&$````$`````@````````"H
M&4```````*@9````````,`8````````$````"P````@`````````&```````
M``!K`````0````8`````````V!]```````#8'P```````!@`````````````
M```````$````````````````````9@````$````&`````````/`?0```````
M\!\````````P!```````````````````!``````````0`````````'$````!
M````!@`````````@)$```````"`D````````^%4``````````````````!``
M``````````````````!W`````0````8`````````&'I````````8>@``````
M``X````````````````````$````````````````````?0````$````"````
M`````$!Z0```````0'H```````#34@``````````````````(```````````
M`````````(4````!`````@`````````4S4```````!3-````````1`$`````
M``````````````0```````````````````"3`````0````(`````````6,Y`
M``````!8S@```````/0$```````````````````(````````````````````
MG0````$````#`````````%#38```````4-,````````0````````````````
M````"````````````````````*0````!`````P````````!@TV```````&#3
M````````$`````````````````````@```````````````````"K`````0``
M``,`````````<--@``````!PTP````````@````````````````````(````
M````````````````L`````8````#`````````'C38```````>-,`````````
M`@````````4`````````"``````````0`````````+D````!`````P``````
M``!XU6```````'C5````````:`````````````````````@`````````"```
M``````"^`````0````,`````````X-5@``````#@U0```````"@"````````
M```````````(``````````@`````````QP````$````#``````````C88```
M````"-@```````!`````````````````````"````````````````````,T`
M```(`````P````````!@V&```````$C8````````T!``````````````````
M`"````````````````````#2`````0````````````````````````!(V```
M`````#`"```````````````````!`````````````````````0````,`````
M````````````````````>-H```````#;`````````````````````0``````
*````````````````
